import { Builder, Subscription, builder, BehaviorSubject } from '@builder.io/sdk';
export { Builder, builder } from '@builder.io/sdk';
import { __extends, __spreadArrays, __assign, __awaiter, __generator, __decorate, __metadata } from 'tslib';
import React from 'react';
import { View, Image as Image$1, Text as Text$1, TouchableOpacity, TextInput, Button as Button$1, Picker } from 'react-native';
import produce from 'immer';
import HTML from 'react-native-render-html';
import ReactNativeVideo from 'react-native-video';

var sizeNames = ['xsmall', 'small', 'medium', 'large'];
// TODO: put in @builder.io/core
var sizes = {
    xsmall: {
        min: 0,
        default: 0,
        max: 0,
    },
    small: {
        min: 320,
        default: 321,
        max: 640,
    },
    medium: {
        min: 641,
        default: 642,
        max: 991,
    },
    large: {
        min: 990,
        default: 991,
        max: 1200,
    },
    getWidthForSize: function (size) {
        return this[size].default;
    },
    getSizeForWidth: function (width) {
        for (var _i = 0, sizeNames_1 = sizeNames; _i < sizeNames_1.length; _i++) {
            var size = sizeNames_1[_i];
            var value = this[size];
            if (width <= value.max) {
                return size;
            }
        }
        return 'large';
    },
};

var BuilderStoreContext = React.createContext({
    state: {},
    update: function (mutator) { return null; },
});

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray = Array.isArray;

/**
 * Gets the last element of `array`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to query.
 * @returns {*} Returns the last element of `array`.
 * @example
 *
 * _.last([1, 2, 3]);
 * // => 3
 */
function last(array) {
  var length = array == null ? 0 : array.length;
  return length ? array[length - 1] : undefined;
}

/** Detect free variable `global` from Node.js. */
var freeGlobal = typeof global == 'object' && global && global.Object === Object && global;

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root = freeGlobal || freeSelf || Function('return this')();

/** Built-in value references. */
var Symbol = root.Symbol;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty = objectProto.hasOwnProperty;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/** Built-in value references. */
var symToStringTag = Symbol ? Symbol.toStringTag : undefined;

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag(value) {
  var isOwn = hasOwnProperty.call(value, symToStringTag),
      tag = value[symToStringTag];

  try {
    value[symToStringTag] = undefined;
    var unmasked = true;
  } catch (e) {}

  var result = nativeObjectToString.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag] = tag;
    } else {
      delete value[symToStringTag];
    }
  }
  return result;
}

/** Used for built-in method references. */
var objectProto$1 = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString$1 = objectProto$1.toString;

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString(value) {
  return nativeObjectToString$1.call(value);
}

/** `Object#toString` result references. */
var nullTag = '[object Null]',
    undefinedTag = '[object Undefined]';

/** Built-in value references. */
var symToStringTag$1 = Symbol ? Symbol.toStringTag : undefined;

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value) {
  if (value == null) {
    return value === undefined ? undefinedTag : nullTag;
  }
  return (symToStringTag$1 && symToStringTag$1 in Object(value))
    ? getRawTag(value)
    : objectToString(value);
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

/** `Object#toString` result references. */
var asyncTag = '[object AsyncFunction]',
    funcTag = '[object Function]',
    genTag = '[object GeneratorFunction]',
    proxyTag = '[object Proxy]';

/**
 * Checks if `value` is classified as a `Function` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * _.isFunction(_);
 * // => true
 *
 * _.isFunction(/abc/);
 * // => false
 */
function isFunction(value) {
  if (!isObject(value)) {
    return false;
  }
  // The use of `Object#toString` avoids issues with the `typeof` operator
  // in Safari 9 which returns 'object' for typed arrays and other constructors.
  var tag = baseGetTag(value);
  return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
}

/** Used to detect overreaching core-js shims. */
var coreJsData = root['__core-js_shared__'];

/** Used to detect methods masquerading as native. */
var maskSrcKey = (function() {
  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
  return uid ? ('Symbol(src)_1.' + uid) : '';
}());

/**
 * Checks if `func` has its source masked.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
 */
function isMasked(func) {
  return !!maskSrcKey && (maskSrcKey in func);
}

/** Used for built-in method references. */
var funcProto = Function.prototype;

/** Used to resolve the decompiled source of functions. */
var funcToString = funcProto.toString;

/**
 * Converts `func` to its source code.
 *
 * @private
 * @param {Function} func The function to convert.
 * @returns {string} Returns the source code.
 */
function toSource(func) {
  if (func != null) {
    try {
      return funcToString.call(func);
    } catch (e) {}
    try {
      return (func + '');
    } catch (e) {}
  }
  return '';
}

/**
 * Used to match `RegExp`
 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
 */
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

/** Used to detect host constructors (Safari). */
var reIsHostCtor = /^\[object .+?Constructor\]$/;

/** Used for built-in method references. */
var funcProto$1 = Function.prototype,
    objectProto$2 = Object.prototype;

/** Used to resolve the decompiled source of functions. */
var funcToString$1 = funcProto$1.toString;

/** Used to check objects for own properties. */
var hasOwnProperty$1 = objectProto$2.hasOwnProperty;

/** Used to detect if a method is native. */
var reIsNative = RegExp('^' +
  funcToString$1.call(hasOwnProperty$1).replace(reRegExpChar, '\\$&')
  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
);

/**
 * The base implementation of `_.isNative` without bad shim checks.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a native function,
 *  else `false`.
 */
function baseIsNative(value) {
  if (!isObject(value) || isMasked(value)) {
    return false;
  }
  var pattern = isFunction(value) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource(value));
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function getValue(object, key) {
  return object == null ? undefined : object[key];
}

/**
 * Gets the native function at `key` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the method to get.
 * @returns {*} Returns the function if it's native, else `undefined`.
 */
function getNative(object, key) {
  var value = getValue(object, key);
  return baseIsNative(value) ? value : undefined;
}

var defineProperty = (function() {
  try {
    var func = getNative(Object, 'defineProperty');
    func({}, '', {});
    return func;
  } catch (e) {}
}());

/**
 * The base implementation of `assignValue` and `assignMergeValue` without
 * value checks.
 *
 * @private
 * @param {Object} object The object to modify.
 * @param {string} key The key of the property to assign.
 * @param {*} value The value to assign.
 */
function baseAssignValue(object, key, value) {
  if (key == '__proto__' && defineProperty) {
    defineProperty(object, key, {
      'configurable': true,
      'enumerable': true,
      'value': value,
      'writable': true
    });
  } else {
    object[key] = value;
  }
}

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */
function eq(value, other) {
  return value === other || (value !== value && other !== other);
}

/** Used for built-in method references. */
var objectProto$3 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$2 = objectProto$3.hasOwnProperty;

/**
 * Assigns `value` to `key` of `object` if the existing value is not equivalent
 * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * for equality comparisons.
 *
 * @private
 * @param {Object} object The object to modify.
 * @param {string} key The key of the property to assign.
 * @param {*} value The value to assign.
 */
function assignValue(object, key, value) {
  var objValue = object[key];
  if (!(hasOwnProperty$2.call(object, key) && eq(objValue, value)) ||
      (value === undefined && !(key in object))) {
    baseAssignValue(object, key, value);
  }
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return value != null && typeof value == 'object';
}

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && baseGetTag(value) == symbolTag);
}

/** Used to match property names within property paths. */
var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,
    reIsPlainProp = /^\w*$/;

/**
 * Checks if `value` is a property name and not a property path.
 *
 * @private
 * @param {*} value The value to check.
 * @param {Object} [object] The object to query keys on.
 * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
 */
function isKey(value, object) {
  if (isArray(value)) {
    return false;
  }
  var type = typeof value;
  if (type == 'number' || type == 'symbol' || type == 'boolean' ||
      value == null || isSymbol(value)) {
    return true;
  }
  return reIsPlainProp.test(value) || !reIsDeepProp.test(value) ||
    (object != null && value in Object(object));
}

/* Built-in method references that are verified to be native. */
var nativeCreate = getNative(Object, 'create');

/**
 * Removes all key-value entries from the hash.
 *
 * @private
 * @name clear
 * @memberOf Hash
 */
function hashClear() {
  this.__data__ = nativeCreate ? nativeCreate(null) : {};
  this.size = 0;
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function hashDelete(key) {
  var result = this.has(key) && delete this.__data__[key];
  this.size -= result ? 1 : 0;
  return result;
}

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED = '__lodash_hash_undefined__';

/** Used for built-in method references. */
var objectProto$4 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$3 = objectProto$4.hasOwnProperty;

/**
 * Gets the hash value for `key`.
 *
 * @private
 * @name get
 * @memberOf Hash
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function hashGet(key) {
  var data = this.__data__;
  if (nativeCreate) {
    var result = data[key];
    return result === HASH_UNDEFINED ? undefined : result;
  }
  return hasOwnProperty$3.call(data, key) ? data[key] : undefined;
}

/** Used for built-in method references. */
var objectProto$5 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$4 = objectProto$5.hasOwnProperty;

/**
 * Checks if a hash value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Hash
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function hashHas(key) {
  var data = this.__data__;
  return nativeCreate ? (data[key] !== undefined) : hasOwnProperty$4.call(data, key);
}

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED$1 = '__lodash_hash_undefined__';

/**
 * Sets the hash `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Hash
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the hash instance.
 */
function hashSet(key, value) {
  var data = this.__data__;
  this.size += this.has(key) ? 0 : 1;
  data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED$1 : value;
  return this;
}

/**
 * Creates a hash object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Hash(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `Hash`.
Hash.prototype.clear = hashClear;
Hash.prototype['delete'] = hashDelete;
Hash.prototype.get = hashGet;
Hash.prototype.has = hashHas;
Hash.prototype.set = hashSet;

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */
function listCacheClear() {
  this.__data__ = [];
  this.size = 0;
}

/**
 * Gets the index at which the `key` is found in `array` of key-value pairs.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} key The key to search for.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function assocIndexOf(array, key) {
  var length = array.length;
  while (length--) {
    if (eq(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}

/** Used for built-in method references. */
var arrayProto = Array.prototype;

/** Built-in value references. */
var splice = arrayProto.splice;

/**
 * Removes `key` and its value from the list cache.
 *
 * @private
 * @name delete
 * @memberOf ListCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function listCacheDelete(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    return false;
  }
  var lastIndex = data.length - 1;
  if (index == lastIndex) {
    data.pop();
  } else {
    splice.call(data, index, 1);
  }
  --this.size;
  return true;
}

/**
 * Gets the list cache value for `key`.
 *
 * @private
 * @name get
 * @memberOf ListCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function listCacheGet(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  return index < 0 ? undefined : data[index][1];
}

/**
 * Checks if a list cache value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf ListCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function listCacheHas(key) {
  return assocIndexOf(this.__data__, key) > -1;
}

/**
 * Sets the list cache `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf ListCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the list cache instance.
 */
function listCacheSet(key, value) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    ++this.size;
    data.push([key, value]);
  } else {
    data[index][1] = value;
  }
  return this;
}

/**
 * Creates an list cache object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function ListCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `ListCache`.
ListCache.prototype.clear = listCacheClear;
ListCache.prototype['delete'] = listCacheDelete;
ListCache.prototype.get = listCacheGet;
ListCache.prototype.has = listCacheHas;
ListCache.prototype.set = listCacheSet;

/* Built-in method references that are verified to be native. */
var Map = getNative(root, 'Map');

/**
 * Removes all key-value entries from the map.
 *
 * @private
 * @name clear
 * @memberOf MapCache
 */
function mapCacheClear() {
  this.size = 0;
  this.__data__ = {
    'hash': new Hash,
    'map': new (Map || ListCache),
    'string': new Hash
  };
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */
function isKeyable(value) {
  var type = typeof value;
  return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
    ? (value !== '__proto__')
    : (value === null);
}

/**
 * Gets the data for `map`.
 *
 * @private
 * @param {Object} map The map to query.
 * @param {string} key The reference key.
 * @returns {*} Returns the map data.
 */
function getMapData(map, key) {
  var data = map.__data__;
  return isKeyable(key)
    ? data[typeof key == 'string' ? 'string' : 'hash']
    : data.map;
}

/**
 * Removes `key` and its value from the map.
 *
 * @private
 * @name delete
 * @memberOf MapCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function mapCacheDelete(key) {
  var result = getMapData(this, key)['delete'](key);
  this.size -= result ? 1 : 0;
  return result;
}

/**
 * Gets the map value for `key`.
 *
 * @private
 * @name get
 * @memberOf MapCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function mapCacheGet(key) {
  return getMapData(this, key).get(key);
}

/**
 * Checks if a map value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf MapCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function mapCacheHas(key) {
  return getMapData(this, key).has(key);
}

/**
 * Sets the map `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf MapCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the map cache instance.
 */
function mapCacheSet(key, value) {
  var data = getMapData(this, key),
      size = data.size;

  data.set(key, value);
  this.size += data.size == size ? 0 : 1;
  return this;
}

/**
 * Creates a map cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function MapCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `MapCache`.
MapCache.prototype.clear = mapCacheClear;
MapCache.prototype['delete'] = mapCacheDelete;
MapCache.prototype.get = mapCacheGet;
MapCache.prototype.has = mapCacheHas;
MapCache.prototype.set = mapCacheSet;

/** Error message constants. */
var FUNC_ERROR_TEXT = 'Expected a function';

/**
 * Creates a function that memoizes the result of `func`. If `resolver` is
 * provided, it determines the cache key for storing the result based on the
 * arguments provided to the memoized function. By default, the first argument
 * provided to the memoized function is used as the map cache key. The `func`
 * is invoked with the `this` binding of the memoized function.
 *
 * **Note:** The cache is exposed as the `cache` property on the memoized
 * function. Its creation may be customized by replacing the `_.memoize.Cache`
 * constructor with one whose instances implement the
 * [`Map`](http://ecma-international.org/ecma-262/7.0/#sec-properties-of-the-map-prototype-object)
 * method interface of `clear`, `delete`, `get`, `has`, and `set`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to have its output memoized.
 * @param {Function} [resolver] The function to resolve the cache key.
 * @returns {Function} Returns the new memoized function.
 * @example
 *
 * var object = { 'a': 1, 'b': 2 };
 * var other = { 'c': 3, 'd': 4 };
 *
 * var values = _.memoize(_.values);
 * values(object);
 * // => [1, 2]
 *
 * values(other);
 * // => [3, 4]
 *
 * object.a = 2;
 * values(object);
 * // => [1, 2]
 *
 * // Modify the result cache.
 * values.cache.set(object, ['a', 'b']);
 * values(object);
 * // => ['a', 'b']
 *
 * // Replace `_.memoize.Cache`.
 * _.memoize.Cache = WeakMap;
 */
function memoize(func, resolver) {
  if (typeof func != 'function' || (resolver != null && typeof resolver != 'function')) {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  var memoized = function() {
    var args = arguments,
        key = resolver ? resolver.apply(this, args) : args[0],
        cache = memoized.cache;

    if (cache.has(key)) {
      return cache.get(key);
    }
    var result = func.apply(this, args);
    memoized.cache = cache.set(key, result) || cache;
    return result;
  };
  memoized.cache = new (memoize.Cache || MapCache);
  return memoized;
}

// Expose `MapCache`.
memoize.Cache = MapCache;

/** Used as the maximum memoize cache size. */
var MAX_MEMOIZE_SIZE = 500;

/**
 * A specialized version of `_.memoize` which clears the memoized function's
 * cache when it exceeds `MAX_MEMOIZE_SIZE`.
 *
 * @private
 * @param {Function} func The function to have its output memoized.
 * @returns {Function} Returns the new memoized function.
 */
function memoizeCapped(func) {
  var result = memoize(func, function(key) {
    if (cache.size === MAX_MEMOIZE_SIZE) {
      cache.clear();
    }
    return key;
  });

  var cache = result.cache;
  return result;
}

/** Used to match property names within property paths. */
var rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;

/** Used to match backslashes in property paths. */
var reEscapeChar = /\\(\\)?/g;

/**
 * Converts `string` to a property path array.
 *
 * @private
 * @param {string} string The string to convert.
 * @returns {Array} Returns the property path array.
 */
var stringToPath = memoizeCapped(function(string) {
  var result = [];
  if (string.charCodeAt(0) === 46 /* . */) {
    result.push('');
  }
  string.replace(rePropName, function(match, number, quote, subString) {
    result.push(quote ? subString.replace(reEscapeChar, '$1') : (number || match));
  });
  return result;
});

/**
 * A specialized version of `_.map` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the new mapped array.
 */
function arrayMap(array, iteratee) {
  var index = -1,
      length = array == null ? 0 : array.length,
      result = Array(length);

  while (++index < length) {
    result[index] = iteratee(array[index], index, array);
  }
  return result;
}

/** Used as references for various `Number` constants. */
var INFINITY = 1 / 0;

/** Used to convert symbols to primitives and strings. */
var symbolProto = Symbol ? Symbol.prototype : undefined,
    symbolToString = symbolProto ? symbolProto.toString : undefined;

/**
 * The base implementation of `_.toString` which doesn't convert nullish
 * values to empty strings.
 *
 * @private
 * @param {*} value The value to process.
 * @returns {string} Returns the string.
 */
function baseToString(value) {
  // Exit early for strings to avoid a performance hit in some environments.
  if (typeof value == 'string') {
    return value;
  }
  if (isArray(value)) {
    // Recursively convert values (susceptible to call stack limits).
    return arrayMap(value, baseToString) + '';
  }
  if (isSymbol(value)) {
    return symbolToString ? symbolToString.call(value) : '';
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
}

/**
 * Converts `value` to a string. An empty string is returned for `null`
 * and `undefined` values. The sign of `-0` is preserved.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 * @example
 *
 * _.toString(null);
 * // => ''
 *
 * _.toString(-0);
 * // => '-0'
 *
 * _.toString([1, 2, 3]);
 * // => '1,2,3'
 */
function toString(value) {
  return value == null ? '' : baseToString(value);
}

/**
 * Casts `value` to a path array if it's not one.
 *
 * @private
 * @param {*} value The value to inspect.
 * @param {Object} [object] The object to query keys on.
 * @returns {Array} Returns the cast property path array.
 */
function castPath(value, object) {
  if (isArray(value)) {
    return value;
  }
  return isKey(value, object) ? [value] : stringToPath(toString(value));
}

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER = 9007199254740991;

/** Used to detect unsigned integer values. */
var reIsUint = /^(?:0|[1-9]\d*)$/;

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @param {*} value The value to check.
 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 */
function isIndex(value, length) {
  var type = typeof value;
  length = length == null ? MAX_SAFE_INTEGER : length;

  return !!length &&
    (type == 'number' ||
      (type != 'symbol' && reIsUint.test(value))) &&
        (value > -1 && value % 1 == 0 && value < length);
}

/** Used as references for various `Number` constants. */
var INFINITY$1 = 1 / 0;

/**
 * Converts `value` to a string key if it's not a string or symbol.
 *
 * @private
 * @param {*} value The value to inspect.
 * @returns {string|symbol} Returns the key.
 */
function toKey(value) {
  if (typeof value == 'string' || isSymbol(value)) {
    return value;
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY$1) ? '-0' : result;
}

/**
 * The base implementation of `_.set`.
 *
 * @private
 * @param {Object} object The object to modify.
 * @param {Array|string} path The path of the property to set.
 * @param {*} value The value to set.
 * @param {Function} [customizer] The function to customize path creation.
 * @returns {Object} Returns `object`.
 */
function baseSet(object, path, value, customizer) {
  if (!isObject(object)) {
    return object;
  }
  path = castPath(path, object);

  var index = -1,
      length = path.length,
      lastIndex = length - 1,
      nested = object;

  while (nested != null && ++index < length) {
    var key = toKey(path[index]),
        newValue = value;

    if (index != lastIndex) {
      var objValue = nested[key];
      newValue = customizer ? customizer(objValue, key, nested) : undefined;
      if (newValue === undefined) {
        newValue = isObject(objValue)
          ? objValue
          : (isIndex(path[index + 1]) ? [] : {});
      }
    }
    assignValue(nested, key, newValue);
    nested = nested[key];
  }
  return object;
}

/**
 * Sets the value at `path` of `object`. If a portion of `path` doesn't exist,
 * it's created. Arrays are created for missing index properties while objects
 * are created for all other missing properties. Use `_.setWith` to customize
 * `path` creation.
 *
 * **Note:** This method mutates `object`.
 *
 * @static
 * @memberOf _
 * @since 3.7.0
 * @category Object
 * @param {Object} object The object to modify.
 * @param {Array|string} path The path of the property to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns `object`.
 * @example
 *
 * var object = { 'a': [{ 'b': { 'c': 3 } }] };
 *
 * _.set(object, 'a[0].b.c', 4);
 * console.log(object.a[0].b.c);
 * // => 4
 *
 * _.set(object, ['x', '0', 'y', 'z'], 5);
 * console.log(object.x[0].y.z);
 * // => 5
 */
function set(object, path, value) {
  return object == null ? object : baseSet(object, path, value);
}

/**
 * The base implementation of `_.findIndex` and `_.findLastIndex` without
 * support for iteratee shorthands.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {Function} predicate The function invoked per iteration.
 * @param {number} fromIndex The index to search from.
 * @param {boolean} [fromRight] Specify iterating from right to left.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function baseFindIndex(array, predicate, fromIndex, fromRight) {
  var length = array.length,
      index = fromIndex + (fromRight ? 1 : -1);

  while ((fromRight ? index-- : ++index < length)) {
    if (predicate(array[index], index, array)) {
      return index;
    }
  }
  return -1;
}

/**
 * The base implementation of `_.isNaN` without support for number objects.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is `NaN`, else `false`.
 */
function baseIsNaN(value) {
  return value !== value;
}

/**
 * A specialized version of `_.indexOf` which performs strict equality
 * comparisons of values, i.e. `===`.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} value The value to search for.
 * @param {number} fromIndex The index to search from.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function strictIndexOf(array, value, fromIndex) {
  var index = fromIndex - 1,
      length = array.length;

  while (++index < length) {
    if (array[index] === value) {
      return index;
    }
  }
  return -1;
}

/**
 * The base implementation of `_.indexOf` without `fromIndex` bounds checks.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} value The value to search for.
 * @param {number} fromIndex The index to search from.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function baseIndexOf(array, value, fromIndex) {
  return value === value
    ? strictIndexOf(array, value, fromIndex)
    : baseFindIndex(array, baseIsNaN, fromIndex);
}

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER$1 = 9007199254740991;

/**
 * Checks if `value` is a valid array-like length.
 *
 * **Note:** This method is loosely based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
 * @example
 *
 * _.isLength(3);
 * // => true
 *
 * _.isLength(Number.MIN_VALUE);
 * // => false
 *
 * _.isLength(Infinity);
 * // => false
 *
 * _.isLength('3');
 * // => false
 */
function isLength(value) {
  return typeof value == 'number' &&
    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER$1;
}

/**
 * Checks if `value` is array-like. A value is considered array-like if it's
 * not a function and has a `value.length` that's an integer greater than or
 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * _.isArrayLike([1, 2, 3]);
 * // => true
 *
 * _.isArrayLike(document.body.children);
 * // => true
 *
 * _.isArrayLike('abc');
 * // => true
 *
 * _.isArrayLike(_.noop);
 * // => false
 */
function isArrayLike(value) {
  return value != null && isLength(value.length) && !isFunction(value);
}

/** `Object#toString` result references. */
var stringTag = '[object String]';

/**
 * Checks if `value` is classified as a `String` primitive or object.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a string, else `false`.
 * @example
 *
 * _.isString('abc');
 * // => true
 *
 * _.isString(1);
 * // => false
 */
function isString(value) {
  return typeof value == 'string' ||
    (!isArray(value) && isObjectLike(value) && baseGetTag(value) == stringTag);
}

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

/** Used as references for various `Number` constants. */
var INFINITY$2 = 1 / 0,
    MAX_INTEGER = 1.7976931348623157e+308;

/**
 * Converts `value` to a finite number.
 *
 * @static
 * @memberOf _
 * @since 4.12.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {number} Returns the converted number.
 * @example
 *
 * _.toFinite(3.2);
 * // => 3.2
 *
 * _.toFinite(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toFinite(Infinity);
 * // => 1.7976931348623157e+308
 *
 * _.toFinite('3.2');
 * // => 3.2
 */
function toFinite(value) {
  if (!value) {
    return value === 0 ? value : 0;
  }
  value = toNumber(value);
  if (value === INFINITY$2 || value === -INFINITY$2) {
    var sign = (value < 0 ? -1 : 1);
    return sign * MAX_INTEGER;
  }
  return value === value ? value : 0;
}

/**
 * Converts `value` to an integer.
 *
 * **Note:** This method is loosely based on
 * [`ToInteger`](http://www.ecma-international.org/ecma-262/7.0/#sec-tointeger).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {number} Returns the converted integer.
 * @example
 *
 * _.toInteger(3.2);
 * // => 3
 *
 * _.toInteger(Number.MIN_VALUE);
 * // => 0
 *
 * _.toInteger(Infinity);
 * // => 1.7976931348623157e+308
 *
 * _.toInteger('3.2');
 * // => 3
 */
function toInteger(value) {
  var result = toFinite(value),
      remainder = result % 1;

  return result === result ? (remainder ? result - remainder : result) : 0;
}

/**
 * The base implementation of `_.values` and `_.valuesIn` which creates an
 * array of `object` property values corresponding to the property names
 * of `props`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array} props The property names to get values for.
 * @returns {Object} Returns the array of property values.
 */
function baseValues(object, props) {
  return arrayMap(props, function(key) {
    return object[key];
  });
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */
function baseTimes(n, iteratee) {
  var index = -1,
      result = Array(n);

  while (++index < n) {
    result[index] = iteratee(index);
  }
  return result;
}

/** `Object#toString` result references. */
var argsTag = '[object Arguments]';

/**
 * The base implementation of `_.isArguments`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 */
function baseIsArguments(value) {
  return isObjectLike(value) && baseGetTag(value) == argsTag;
}

/** Used for built-in method references. */
var objectProto$6 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$5 = objectProto$6.hasOwnProperty;

/** Built-in value references. */
var propertyIsEnumerable = objectProto$6.propertyIsEnumerable;

/**
 * Checks if `value` is likely an `arguments` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 *  else `false`.
 * @example
 *
 * _.isArguments(function() { return arguments; }());
 * // => true
 *
 * _.isArguments([1, 2, 3]);
 * // => false
 */
var isArguments = baseIsArguments(function() { return arguments; }()) ? baseIsArguments : function(value) {
  return isObjectLike(value) && hasOwnProperty$5.call(value, 'callee') &&
    !propertyIsEnumerable.call(value, 'callee');
};

/**
 * This method returns `false`.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {boolean} Returns `false`.
 * @example
 *
 * _.times(2, _.stubFalse);
 * // => [false, false]
 */
function stubFalse() {
  return false;
}

/** Detect free variable `exports`. */
var freeExports = typeof exports == 'object' && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule = freeExports && typeof module == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports = freeModule && freeModule.exports === freeExports;

/** Built-in value references. */
var Buffer = moduleExports ? root.Buffer : undefined;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined;

/**
 * Checks if `value` is a buffer.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
 * @example
 *
 * _.isBuffer(new Buffer(2));
 * // => true
 *
 * _.isBuffer(new Uint8Array(2));
 * // => false
 */
var isBuffer = nativeIsBuffer || stubFalse;

/** `Object#toString` result references. */
var argsTag$1 = '[object Arguments]',
    arrayTag = '[object Array]',
    boolTag = '[object Boolean]',
    dateTag = '[object Date]',
    errorTag = '[object Error]',
    funcTag$1 = '[object Function]',
    mapTag = '[object Map]',
    numberTag = '[object Number]',
    objectTag = '[object Object]',
    regexpTag = '[object RegExp]',
    setTag = '[object Set]',
    stringTag$1 = '[object String]',
    weakMapTag = '[object WeakMap]';

var arrayBufferTag = '[object ArrayBuffer]',
    dataViewTag = '[object DataView]',
    float32Tag = '[object Float32Array]',
    float64Tag = '[object Float64Array]',
    int8Tag = '[object Int8Array]',
    int16Tag = '[object Int16Array]',
    int32Tag = '[object Int32Array]',
    uint8Tag = '[object Uint8Array]',
    uint8ClampedTag = '[object Uint8ClampedArray]',
    uint16Tag = '[object Uint16Array]',
    uint32Tag = '[object Uint32Array]';

/** Used to identify `toStringTag` values of typed arrays. */
var typedArrayTags = {};
typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
typedArrayTags[uint32Tag] = true;
typedArrayTags[argsTag$1] = typedArrayTags[arrayTag] =
typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
typedArrayTags[errorTag] = typedArrayTags[funcTag$1] =
typedArrayTags[mapTag] = typedArrayTags[numberTag] =
typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
typedArrayTags[setTag] = typedArrayTags[stringTag$1] =
typedArrayTags[weakMapTag] = false;

/**
 * The base implementation of `_.isTypedArray` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 */
function baseIsTypedArray(value) {
  return isObjectLike(value) &&
    isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */
function baseUnary(func) {
  return function(value) {
    return func(value);
  };
}

/** Detect free variable `exports`. */
var freeExports$1 = typeof exports == 'object' && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule$1 = freeExports$1 && typeof module == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports$1 = freeModule$1 && freeModule$1.exports === freeExports$1;

/** Detect free variable `process` from Node.js. */
var freeProcess = moduleExports$1 && freeGlobal.process;

/** Used to access faster Node.js helpers. */
var nodeUtil = (function() {
  try {
    // Use `util.types` for Node.js 10+.
    var types = freeModule$1 && freeModule$1.require && freeModule$1.require('util').types;

    if (types) {
      return types;
    }

    // Legacy `process.binding('util')` for Node.js < 10.
    return freeProcess && freeProcess.binding && freeProcess.binding('util');
  } catch (e) {}
}());

/* Node.js helper references. */
var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;

/**
 * Checks if `value` is classified as a typed array.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 * @example
 *
 * _.isTypedArray(new Uint8Array);
 * // => true
 *
 * _.isTypedArray([]);
 * // => false
 */
var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;

/** Used for built-in method references. */
var objectProto$7 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$6 = objectProto$7.hasOwnProperty;

/**
 * Creates an array of the enumerable property names of the array-like `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @param {boolean} inherited Specify returning inherited property names.
 * @returns {Array} Returns the array of property names.
 */
function arrayLikeKeys(value, inherited) {
  var isArr = isArray(value),
      isArg = !isArr && isArguments(value),
      isBuff = !isArr && !isArg && isBuffer(value),
      isType = !isArr && !isArg && !isBuff && isTypedArray(value),
      skipIndexes = isArr || isArg || isBuff || isType,
      result = skipIndexes ? baseTimes(value.length, String) : [],
      length = result.length;

  for (var key in value) {
    if ((inherited || hasOwnProperty$6.call(value, key)) &&
        !(skipIndexes && (
           // Safari 9 has enumerable `arguments.length` in strict mode.
           key == 'length' ||
           // Node.js 0.10 has enumerable non-index properties on buffers.
           (isBuff && (key == 'offset' || key == 'parent')) ||
           // PhantomJS 2 has enumerable non-index properties on typed arrays.
           (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
           // Skip index properties.
           isIndex(key, length)
        ))) {
      result.push(key);
    }
  }
  return result;
}

/** Used for built-in method references. */
var objectProto$8 = Object.prototype;

/**
 * Checks if `value` is likely a prototype object.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
 */
function isPrototype(value) {
  var Ctor = value && value.constructor,
      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto$8;

  return value === proto;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */
function overArg(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeKeys = overArg(Object.keys, Object);

/** Used for built-in method references. */
var objectProto$9 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$7 = objectProto$9.hasOwnProperty;

/**
 * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeys(object) {
  if (!isPrototype(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty$7.call(object, key) && key != 'constructor') {
      result.push(key);
    }
  }
  return result;
}

/**
 * Creates an array of the own enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects. See the
 * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * for more details.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keys(new Foo);
 * // => ['a', 'b'] (iteration order is not guaranteed)
 *
 * _.keys('hi');
 * // => ['0', '1']
 */
function keys(object) {
  return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
}

/**
 * Creates an array of the own enumerable string keyed property values of `object`.
 *
 * **Note:** Non-object values are coerced to objects.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property values.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.values(new Foo);
 * // => [1, 2] (iteration order is not guaranteed)
 *
 * _.values('hi');
 * // => ['h', 'i']
 */
function values(object) {
  return object == null ? [] : baseValues(object, keys(object));
}

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax = Math.max;

/**
 * Checks if `value` is in `collection`. If `collection` is a string, it's
 * checked for a substring of `value`, otherwise
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * is used for equality comparisons. If `fromIndex` is negative, it's used as
 * the offset from the end of `collection`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Collection
 * @param {Array|Object|string} collection The collection to inspect.
 * @param {*} value The value to search for.
 * @param {number} [fromIndex=0] The index to search from.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.reduce`.
 * @returns {boolean} Returns `true` if `value` is found, else `false`.
 * @example
 *
 * _.includes([1, 2, 3], 1);
 * // => true
 *
 * _.includes([1, 2, 3], 1, 2);
 * // => false
 *
 * _.includes({ 'a': 1, 'b': 2 }, 1);
 * // => true
 *
 * _.includes('abcd', 'bc');
 * // => true
 */
function includes(collection, value, fromIndex, guard) {
  collection = isArrayLike(collection) ? collection : values(collection);
  fromIndex = (fromIndex && !guard) ? toInteger(fromIndex) : 0;

  var length = collection.length;
  if (fromIndex < 0) {
    fromIndex = nativeMax(length + fromIndex, 0);
  }
  return isString(collection)
    ? (fromIndex <= length && collection.indexOf(value, fromIndex) > -1)
    : (!!length && baseIndexOf(collection, value, fromIndex) > -1);
}

/**
 * Removes all key-value entries from the stack.
 *
 * @private
 * @name clear
 * @memberOf Stack
 */
function stackClear() {
  this.__data__ = new ListCache;
  this.size = 0;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function stackDelete(key) {
  var data = this.__data__,
      result = data['delete'](key);

  this.size = data.size;
  return result;
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function stackGet(key) {
  return this.__data__.get(key);
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function stackHas(key) {
  return this.__data__.has(key);
}

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/**
 * Sets the stack `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Stack
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the stack cache instance.
 */
function stackSet(key, value) {
  var data = this.__data__;
  if (data instanceof ListCache) {
    var pairs = data.__data__;
    if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
      pairs.push([key, value]);
      this.size = ++data.size;
      return this;
    }
    data = this.__data__ = new MapCache(pairs);
  }
  data.set(key, value);
  this.size = data.size;
  return this;
}

/**
 * Creates a stack cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Stack(entries) {
  var data = this.__data__ = new ListCache(entries);
  this.size = data.size;
}

// Add methods to `Stack`.
Stack.prototype.clear = stackClear;
Stack.prototype['delete'] = stackDelete;
Stack.prototype.get = stackGet;
Stack.prototype.has = stackHas;
Stack.prototype.set = stackSet;

/**
 * A specialized version of `_.forEach` for arrays without support for
 * iteratee shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns `array`.
 */
function arrayEach(array, iteratee) {
  var index = -1,
      length = array == null ? 0 : array.length;

  while (++index < length) {
    if (iteratee(array[index], index, array) === false) {
      break;
    }
  }
  return array;
}

/**
 * Copies properties of `source` to `object`.
 *
 * @private
 * @param {Object} source The object to copy properties from.
 * @param {Array} props The property identifiers to copy.
 * @param {Object} [object={}] The object to copy properties to.
 * @param {Function} [customizer] The function to customize copied values.
 * @returns {Object} Returns `object`.
 */
function copyObject(source, props, object, customizer) {
  var isNew = !object;
  object || (object = {});

  var index = -1,
      length = props.length;

  while (++index < length) {
    var key = props[index];

    var newValue = customizer
      ? customizer(object[key], source[key], key, object, source)
      : undefined;

    if (newValue === undefined) {
      newValue = source[key];
    }
    if (isNew) {
      baseAssignValue(object, key, newValue);
    } else {
      assignValue(object, key, newValue);
    }
  }
  return object;
}

/**
 * The base implementation of `_.assign` without support for multiple sources
 * or `customizer` functions.
 *
 * @private
 * @param {Object} object The destination object.
 * @param {Object} source The source object.
 * @returns {Object} Returns `object`.
 */
function baseAssign(object, source) {
  return object && copyObject(source, keys(source), object);
}

/**
 * This function is like
 * [`Object.keys`](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * except that it includes inherited enumerable properties.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function nativeKeysIn(object) {
  var result = [];
  if (object != null) {
    for (var key in Object(object)) {
      result.push(key);
    }
  }
  return result;
}

/** Used for built-in method references. */
var objectProto$a = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$8 = objectProto$a.hasOwnProperty;

/**
 * The base implementation of `_.keysIn` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeysIn(object) {
  if (!isObject(object)) {
    return nativeKeysIn(object);
  }
  var isProto = isPrototype(object),
      result = [];

  for (var key in object) {
    if (!(key == 'constructor' && (isProto || !hasOwnProperty$8.call(object, key)))) {
      result.push(key);
    }
  }
  return result;
}

/**
 * Creates an array of the own and inherited enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keysIn(new Foo);
 * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
 */
function keysIn$1(object) {
  return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
}

/**
 * The base implementation of `_.assignIn` without support for multiple sources
 * or `customizer` functions.
 *
 * @private
 * @param {Object} object The destination object.
 * @param {Object} source The source object.
 * @returns {Object} Returns `object`.
 */
function baseAssignIn(object, source) {
  return object && copyObject(source, keysIn$1(source), object);
}

/** Detect free variable `exports`. */
var freeExports$2 = typeof exports == 'object' && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule$2 = freeExports$2 && typeof module == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports$2 = freeModule$2 && freeModule$2.exports === freeExports$2;

/** Built-in value references. */
var Buffer$1 = moduleExports$2 ? root.Buffer : undefined,
    allocUnsafe = Buffer$1 ? Buffer$1.allocUnsafe : undefined;

/**
 * Creates a clone of  `buffer`.
 *
 * @private
 * @param {Buffer} buffer The buffer to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @returns {Buffer} Returns the cloned buffer.
 */
function cloneBuffer(buffer, isDeep) {
  if (isDeep) {
    return buffer.slice();
  }
  var length = buffer.length,
      result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);

  buffer.copy(result);
  return result;
}

/**
 * Copies the values of `source` to `array`.
 *
 * @private
 * @param {Array} source The array to copy values from.
 * @param {Array} [array=[]] The array to copy values to.
 * @returns {Array} Returns `array`.
 */
function copyArray(source, array) {
  var index = -1,
      length = source.length;

  array || (array = Array(length));
  while (++index < length) {
    array[index] = source[index];
  }
  return array;
}

/**
 * A specialized version of `_.filter` for arrays without support for
 * iteratee shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {Array} Returns the new filtered array.
 */
function arrayFilter(array, predicate) {
  var index = -1,
      length = array == null ? 0 : array.length,
      resIndex = 0,
      result = [];

  while (++index < length) {
    var value = array[index];
    if (predicate(value, index, array)) {
      result[resIndex++] = value;
    }
  }
  return result;
}

/**
 * This method returns a new empty array.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {Array} Returns the new empty array.
 * @example
 *
 * var arrays = _.times(2, _.stubArray);
 *
 * console.log(arrays);
 * // => [[], []]
 *
 * console.log(arrays[0] === arrays[1]);
 * // => false
 */
function stubArray() {
  return [];
}

/** Used for built-in method references. */
var objectProto$b = Object.prototype;

/** Built-in value references. */
var propertyIsEnumerable$1 = objectProto$b.propertyIsEnumerable;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeGetSymbols = Object.getOwnPropertySymbols;

/**
 * Creates an array of the own enumerable symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of symbols.
 */
var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
  if (object == null) {
    return [];
  }
  object = Object(object);
  return arrayFilter(nativeGetSymbols(object), function(symbol) {
    return propertyIsEnumerable$1.call(object, symbol);
  });
};

/**
 * Copies own symbols of `source` to `object`.
 *
 * @private
 * @param {Object} source The object to copy symbols from.
 * @param {Object} [object={}] The object to copy symbols to.
 * @returns {Object} Returns `object`.
 */
function copySymbols(source, object) {
  return copyObject(source, getSymbols(source), object);
}

/**
 * Appends the elements of `values` to `array`.
 *
 * @private
 * @param {Array} array The array to modify.
 * @param {Array} values The values to append.
 * @returns {Array} Returns `array`.
 */
function arrayPush(array, values) {
  var index = -1,
      length = values.length,
      offset = array.length;

  while (++index < length) {
    array[offset + index] = values[index];
  }
  return array;
}

/** Built-in value references. */
var getPrototype = overArg(Object.getPrototypeOf, Object);

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeGetSymbols$1 = Object.getOwnPropertySymbols;

/**
 * Creates an array of the own and inherited enumerable symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of symbols.
 */
var getSymbolsIn = !nativeGetSymbols$1 ? stubArray : function(object) {
  var result = [];
  while (object) {
    arrayPush(result, getSymbols(object));
    object = getPrototype(object);
  }
  return result;
};

/**
 * Copies own and inherited symbols of `source` to `object`.
 *
 * @private
 * @param {Object} source The object to copy symbols from.
 * @param {Object} [object={}] The object to copy symbols to.
 * @returns {Object} Returns `object`.
 */
function copySymbolsIn(source, object) {
  return copyObject(source, getSymbolsIn(source), object);
}

/**
 * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
 * `keysFunc` and `symbolsFunc` to get the enumerable property names and
 * symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @param {Function} symbolsFunc The function to get the symbols of `object`.
 * @returns {Array} Returns the array of property names and symbols.
 */
function baseGetAllKeys(object, keysFunc, symbolsFunc) {
  var result = keysFunc(object);
  return isArray(object) ? result : arrayPush(result, symbolsFunc(object));
}

/**
 * Creates an array of own enumerable property names and symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names and symbols.
 */
function getAllKeys(object) {
  return baseGetAllKeys(object, keys, getSymbols);
}

/**
 * Creates an array of own and inherited enumerable property names and
 * symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names and symbols.
 */
function getAllKeysIn(object) {
  return baseGetAllKeys(object, keysIn$1, getSymbolsIn);
}

/* Built-in method references that are verified to be native. */
var DataView = getNative(root, 'DataView');

/* Built-in method references that are verified to be native. */
var Promise$1 = getNative(root, 'Promise');

/* Built-in method references that are verified to be native. */
var Set = getNative(root, 'Set');

/* Built-in method references that are verified to be native. */
var WeakMap = getNative(root, 'WeakMap');

/** `Object#toString` result references. */
var mapTag$1 = '[object Map]',
    objectTag$1 = '[object Object]',
    promiseTag = '[object Promise]',
    setTag$1 = '[object Set]',
    weakMapTag$1 = '[object WeakMap]';

var dataViewTag$1 = '[object DataView]';

/** Used to detect maps, sets, and weakmaps. */
var dataViewCtorString = toSource(DataView),
    mapCtorString = toSource(Map),
    promiseCtorString = toSource(Promise$1),
    setCtorString = toSource(Set),
    weakMapCtorString = toSource(WeakMap);

/**
 * Gets the `toStringTag` of `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
var getTag = baseGetTag;

// Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
if ((DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag$1) ||
    (Map && getTag(new Map) != mapTag$1) ||
    (Promise$1 && getTag(Promise$1.resolve()) != promiseTag) ||
    (Set && getTag(new Set) != setTag$1) ||
    (WeakMap && getTag(new WeakMap) != weakMapTag$1)) {
  getTag = function(value) {
    var result = baseGetTag(value),
        Ctor = result == objectTag$1 ? value.constructor : undefined,
        ctorString = Ctor ? toSource(Ctor) : '';

    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString: return dataViewTag$1;
        case mapCtorString: return mapTag$1;
        case promiseCtorString: return promiseTag;
        case setCtorString: return setTag$1;
        case weakMapCtorString: return weakMapTag$1;
      }
    }
    return result;
  };
}

var getTag$1 = getTag;

/** Used for built-in method references. */
var objectProto$c = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$9 = objectProto$c.hasOwnProperty;

/**
 * Initializes an array clone.
 *
 * @private
 * @param {Array} array The array to clone.
 * @returns {Array} Returns the initialized clone.
 */
function initCloneArray(array) {
  var length = array.length,
      result = new array.constructor(length);

  // Add properties assigned by `RegExp#exec`.
  if (length && typeof array[0] == 'string' && hasOwnProperty$9.call(array, 'index')) {
    result.index = array.index;
    result.input = array.input;
  }
  return result;
}

/** Built-in value references. */
var Uint8Array = root.Uint8Array;

/**
 * Creates a clone of `arrayBuffer`.
 *
 * @private
 * @param {ArrayBuffer} arrayBuffer The array buffer to clone.
 * @returns {ArrayBuffer} Returns the cloned array buffer.
 */
function cloneArrayBuffer(arrayBuffer) {
  var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
  new Uint8Array(result).set(new Uint8Array(arrayBuffer));
  return result;
}

/**
 * Creates a clone of `dataView`.
 *
 * @private
 * @param {Object} dataView The data view to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @returns {Object} Returns the cloned data view.
 */
function cloneDataView(dataView, isDeep) {
  var buffer = isDeep ? cloneArrayBuffer(dataView.buffer) : dataView.buffer;
  return new dataView.constructor(buffer, dataView.byteOffset, dataView.byteLength);
}

/** Used to match `RegExp` flags from their coerced string values. */
var reFlags = /\w*$/;

/**
 * Creates a clone of `regexp`.
 *
 * @private
 * @param {Object} regexp The regexp to clone.
 * @returns {Object} Returns the cloned regexp.
 */
function cloneRegExp(regexp) {
  var result = new regexp.constructor(regexp.source, reFlags.exec(regexp));
  result.lastIndex = regexp.lastIndex;
  return result;
}

/** Used to convert symbols to primitives and strings. */
var symbolProto$1 = Symbol ? Symbol.prototype : undefined,
    symbolValueOf = symbolProto$1 ? symbolProto$1.valueOf : undefined;

/**
 * Creates a clone of the `symbol` object.
 *
 * @private
 * @param {Object} symbol The symbol object to clone.
 * @returns {Object} Returns the cloned symbol object.
 */
function cloneSymbol(symbol) {
  return symbolValueOf ? Object(symbolValueOf.call(symbol)) : {};
}

/**
 * Creates a clone of `typedArray`.
 *
 * @private
 * @param {Object} typedArray The typed array to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @returns {Object} Returns the cloned typed array.
 */
function cloneTypedArray(typedArray, isDeep) {
  var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
  return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
}

/** `Object#toString` result references. */
var boolTag$1 = '[object Boolean]',
    dateTag$1 = '[object Date]',
    mapTag$2 = '[object Map]',
    numberTag$1 = '[object Number]',
    regexpTag$1 = '[object RegExp]',
    setTag$2 = '[object Set]',
    stringTag$2 = '[object String]',
    symbolTag$1 = '[object Symbol]';

var arrayBufferTag$1 = '[object ArrayBuffer]',
    dataViewTag$2 = '[object DataView]',
    float32Tag$1 = '[object Float32Array]',
    float64Tag$1 = '[object Float64Array]',
    int8Tag$1 = '[object Int8Array]',
    int16Tag$1 = '[object Int16Array]',
    int32Tag$1 = '[object Int32Array]',
    uint8Tag$1 = '[object Uint8Array]',
    uint8ClampedTag$1 = '[object Uint8ClampedArray]',
    uint16Tag$1 = '[object Uint16Array]',
    uint32Tag$1 = '[object Uint32Array]';

/**
 * Initializes an object clone based on its `toStringTag`.
 *
 * **Note:** This function only supports cloning values with tags of
 * `Boolean`, `Date`, `Error`, `Map`, `Number`, `RegExp`, `Set`, or `String`.
 *
 * @private
 * @param {Object} object The object to clone.
 * @param {string} tag The `toStringTag` of the object to clone.
 * @param {boolean} [isDeep] Specify a deep clone.
 * @returns {Object} Returns the initialized clone.
 */
function initCloneByTag(object, tag, isDeep) {
  var Ctor = object.constructor;
  switch (tag) {
    case arrayBufferTag$1:
      return cloneArrayBuffer(object);

    case boolTag$1:
    case dateTag$1:
      return new Ctor(+object);

    case dataViewTag$2:
      return cloneDataView(object, isDeep);

    case float32Tag$1: case float64Tag$1:
    case int8Tag$1: case int16Tag$1: case int32Tag$1:
    case uint8Tag$1: case uint8ClampedTag$1: case uint16Tag$1: case uint32Tag$1:
      return cloneTypedArray(object, isDeep);

    case mapTag$2:
      return new Ctor;

    case numberTag$1:
    case stringTag$2:
      return new Ctor(object);

    case regexpTag$1:
      return cloneRegExp(object);

    case setTag$2:
      return new Ctor;

    case symbolTag$1:
      return cloneSymbol(object);
  }
}

/** Built-in value references. */
var objectCreate = Object.create;

/**
 * The base implementation of `_.create` without support for assigning
 * properties to the created object.
 *
 * @private
 * @param {Object} proto The object to inherit from.
 * @returns {Object} Returns the new object.
 */
var baseCreate = (function() {
  function object() {}
  return function(proto) {
    if (!isObject(proto)) {
      return {};
    }
    if (objectCreate) {
      return objectCreate(proto);
    }
    object.prototype = proto;
    var result = new object;
    object.prototype = undefined;
    return result;
  };
}());

/**
 * Initializes an object clone.
 *
 * @private
 * @param {Object} object The object to clone.
 * @returns {Object} Returns the initialized clone.
 */
function initCloneObject(object) {
  return (typeof object.constructor == 'function' && !isPrototype(object))
    ? baseCreate(getPrototype(object))
    : {};
}

/** `Object#toString` result references. */
var mapTag$3 = '[object Map]';

/**
 * The base implementation of `_.isMap` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a map, else `false`.
 */
function baseIsMap(value) {
  return isObjectLike(value) && getTag$1(value) == mapTag$3;
}

/* Node.js helper references. */
var nodeIsMap = nodeUtil && nodeUtil.isMap;

/**
 * Checks if `value` is classified as a `Map` object.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a map, else `false`.
 * @example
 *
 * _.isMap(new Map);
 * // => true
 *
 * _.isMap(new WeakMap);
 * // => false
 */
var isMap = nodeIsMap ? baseUnary(nodeIsMap) : baseIsMap;

/** `Object#toString` result references. */
var setTag$3 = '[object Set]';

/**
 * The base implementation of `_.isSet` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a set, else `false`.
 */
function baseIsSet(value) {
  return isObjectLike(value) && getTag$1(value) == setTag$3;
}

/* Node.js helper references. */
var nodeIsSet = nodeUtil && nodeUtil.isSet;

/**
 * Checks if `value` is classified as a `Set` object.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a set, else `false`.
 * @example
 *
 * _.isSet(new Set);
 * // => true
 *
 * _.isSet(new WeakSet);
 * // => false
 */
var isSet = nodeIsSet ? baseUnary(nodeIsSet) : baseIsSet;

/** Used to compose bitmasks for cloning. */
var CLONE_DEEP_FLAG = 1,
    CLONE_FLAT_FLAG = 2,
    CLONE_SYMBOLS_FLAG = 4;

/** `Object#toString` result references. */
var argsTag$2 = '[object Arguments]',
    arrayTag$1 = '[object Array]',
    boolTag$2 = '[object Boolean]',
    dateTag$2 = '[object Date]',
    errorTag$1 = '[object Error]',
    funcTag$2 = '[object Function]',
    genTag$1 = '[object GeneratorFunction]',
    mapTag$4 = '[object Map]',
    numberTag$2 = '[object Number]',
    objectTag$2 = '[object Object]',
    regexpTag$2 = '[object RegExp]',
    setTag$4 = '[object Set]',
    stringTag$3 = '[object String]',
    symbolTag$2 = '[object Symbol]',
    weakMapTag$2 = '[object WeakMap]';

var arrayBufferTag$2 = '[object ArrayBuffer]',
    dataViewTag$3 = '[object DataView]',
    float32Tag$2 = '[object Float32Array]',
    float64Tag$2 = '[object Float64Array]',
    int8Tag$2 = '[object Int8Array]',
    int16Tag$2 = '[object Int16Array]',
    int32Tag$2 = '[object Int32Array]',
    uint8Tag$2 = '[object Uint8Array]',
    uint8ClampedTag$2 = '[object Uint8ClampedArray]',
    uint16Tag$2 = '[object Uint16Array]',
    uint32Tag$2 = '[object Uint32Array]';

/** Used to identify `toStringTag` values supported by `_.clone`. */
var cloneableTags = {};
cloneableTags[argsTag$2] = cloneableTags[arrayTag$1] =
cloneableTags[arrayBufferTag$2] = cloneableTags[dataViewTag$3] =
cloneableTags[boolTag$2] = cloneableTags[dateTag$2] =
cloneableTags[float32Tag$2] = cloneableTags[float64Tag$2] =
cloneableTags[int8Tag$2] = cloneableTags[int16Tag$2] =
cloneableTags[int32Tag$2] = cloneableTags[mapTag$4] =
cloneableTags[numberTag$2] = cloneableTags[objectTag$2] =
cloneableTags[regexpTag$2] = cloneableTags[setTag$4] =
cloneableTags[stringTag$3] = cloneableTags[symbolTag$2] =
cloneableTags[uint8Tag$2] = cloneableTags[uint8ClampedTag$2] =
cloneableTags[uint16Tag$2] = cloneableTags[uint32Tag$2] = true;
cloneableTags[errorTag$1] = cloneableTags[funcTag$2] =
cloneableTags[weakMapTag$2] = false;

/**
 * The base implementation of `_.clone` and `_.cloneDeep` which tracks
 * traversed objects.
 *
 * @private
 * @param {*} value The value to clone.
 * @param {boolean} bitmask The bitmask flags.
 *  1 - Deep clone
 *  2 - Flatten inherited properties
 *  4 - Clone symbols
 * @param {Function} [customizer] The function to customize cloning.
 * @param {string} [key] The key of `value`.
 * @param {Object} [object] The parent object of `value`.
 * @param {Object} [stack] Tracks traversed objects and their clone counterparts.
 * @returns {*} Returns the cloned value.
 */
function baseClone(value, bitmask, customizer, key, object, stack) {
  var result,
      isDeep = bitmask & CLONE_DEEP_FLAG,
      isFlat = bitmask & CLONE_FLAT_FLAG,
      isFull = bitmask & CLONE_SYMBOLS_FLAG;

  if (customizer) {
    result = object ? customizer(value, key, object, stack) : customizer(value);
  }
  if (result !== undefined) {
    return result;
  }
  if (!isObject(value)) {
    return value;
  }
  var isArr = isArray(value);
  if (isArr) {
    result = initCloneArray(value);
    if (!isDeep) {
      return copyArray(value, result);
    }
  } else {
    var tag = getTag$1(value),
        isFunc = tag == funcTag$2 || tag == genTag$1;

    if (isBuffer(value)) {
      return cloneBuffer(value, isDeep);
    }
    if (tag == objectTag$2 || tag == argsTag$2 || (isFunc && !object)) {
      result = (isFlat || isFunc) ? {} : initCloneObject(value);
      if (!isDeep) {
        return isFlat
          ? copySymbolsIn(value, baseAssignIn(result, value))
          : copySymbols(value, baseAssign(result, value));
      }
    } else {
      if (!cloneableTags[tag]) {
        return object ? value : {};
      }
      result = initCloneByTag(value, tag, isDeep);
    }
  }
  // Check for circular references and return its corresponding clone.
  stack || (stack = new Stack);
  var stacked = stack.get(value);
  if (stacked) {
    return stacked;
  }
  stack.set(value, result);

  if (isSet(value)) {
    value.forEach(function(subValue) {
      result.add(baseClone(subValue, bitmask, customizer, subValue, value, stack));
    });
  } else if (isMap(value)) {
    value.forEach(function(subValue, key) {
      result.set(key, baseClone(subValue, bitmask, customizer, key, value, stack));
    });
  }

  var keysFunc = isFull
    ? (isFlat ? getAllKeysIn : getAllKeys)
    : (isFlat ? keysIn : keys);

  var props = isArr ? undefined : keysFunc(value);
  arrayEach(props || value, function(subValue, key) {
    if (props) {
      key = subValue;
      subValue = value[key];
    }
    // Recursively populate clone (susceptible to call stack limits).
    assignValue(result, key, baseClone(subValue, bitmask, customizer, key, value, stack));
  });
  return result;
}

/**
 * The base implementation of `_.get` without support for default values.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path of the property to get.
 * @returns {*} Returns the resolved value.
 */
function baseGet(object, path) {
  path = castPath(path, object);

  var index = 0,
      length = path.length;

  while (object != null && index < length) {
    object = object[toKey(path[index++])];
  }
  return (index && index == length) ? object : undefined;
}

/**
 * The base implementation of `_.slice` without an iteratee call guard.
 *
 * @private
 * @param {Array} array The array to slice.
 * @param {number} [start=0] The start position.
 * @param {number} [end=array.length] The end position.
 * @returns {Array} Returns the slice of `array`.
 */
function baseSlice(array, start, end) {
  var index = -1,
      length = array.length;

  if (start < 0) {
    start = -start > length ? 0 : (length + start);
  }
  end = end > length ? length : end;
  if (end < 0) {
    end += length;
  }
  length = start > end ? 0 : ((end - start) >>> 0);
  start >>>= 0;

  var result = Array(length);
  while (++index < length) {
    result[index] = array[index + start];
  }
  return result;
}

/**
 * Gets the parent value at `path` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array} path The path to get the parent value of.
 * @returns {*} Returns the parent value.
 */
function parent$1(object, path) {
  return path.length < 2 ? object : baseGet(object, baseSlice(path, 0, -1));
}

/**
 * The base implementation of `_.unset`.
 *
 * @private
 * @param {Object} object The object to modify.
 * @param {Array|string} path The property path to unset.
 * @returns {boolean} Returns `true` if the property is deleted, else `false`.
 */
function baseUnset(object, path) {
  path = castPath(path, object);
  object = parent$1(object, path);
  return object == null || delete object[toKey(last(path))];
}

/** `Object#toString` result references. */
var objectTag$3 = '[object Object]';

/** Used for built-in method references. */
var funcProto$2 = Function.prototype,
    objectProto$d = Object.prototype;

/** Used to resolve the decompiled source of functions. */
var funcToString$2 = funcProto$2.toString;

/** Used to check objects for own properties. */
var hasOwnProperty$a = objectProto$d.hasOwnProperty;

/** Used to infer the `Object` constructor. */
var objectCtorString = funcToString$2.call(Object);

/**
 * Checks if `value` is a plain object, that is, an object created by the
 * `Object` constructor or one with a `[[Prototype]]` of `null`.
 *
 * @static
 * @memberOf _
 * @since 0.8.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 * }
 *
 * _.isPlainObject(new Foo);
 * // => false
 *
 * _.isPlainObject([1, 2, 3]);
 * // => false
 *
 * _.isPlainObject({ 'x': 0, 'y': 0 });
 * // => true
 *
 * _.isPlainObject(Object.create(null));
 * // => true
 */
function isPlainObject(value) {
  if (!isObjectLike(value) || baseGetTag(value) != objectTag$3) {
    return false;
  }
  var proto = getPrototype(value);
  if (proto === null) {
    return true;
  }
  var Ctor = hasOwnProperty$a.call(proto, 'constructor') && proto.constructor;
  return typeof Ctor == 'function' && Ctor instanceof Ctor &&
    funcToString$2.call(Ctor) == objectCtorString;
}

/**
 * Used by `_.omit` to customize its `_.cloneDeep` use to only clone plain
 * objects.
 *
 * @private
 * @param {*} value The value to inspect.
 * @param {string} key The key of the property to inspect.
 * @returns {*} Returns the uncloned value or `undefined` to defer cloning to `_.cloneDeep`.
 */
function customOmitClone(value) {
  return isPlainObject(value) ? undefined : value;
}

/** Built-in value references. */
var spreadableSymbol = Symbol ? Symbol.isConcatSpreadable : undefined;

/**
 * Checks if `value` is a flattenable `arguments` object or array.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.
 */
function isFlattenable(value) {
  return isArray(value) || isArguments(value) ||
    !!(spreadableSymbol && value && value[spreadableSymbol]);
}

/**
 * The base implementation of `_.flatten` with support for restricting flattening.
 *
 * @private
 * @param {Array} array The array to flatten.
 * @param {number} depth The maximum recursion depth.
 * @param {boolean} [predicate=isFlattenable] The function invoked per iteration.
 * @param {boolean} [isStrict] Restrict to values that pass `predicate` checks.
 * @param {Array} [result=[]] The initial result value.
 * @returns {Array} Returns the new flattened array.
 */
function baseFlatten(array, depth, predicate, isStrict, result) {
  var index = -1,
      length = array.length;

  predicate || (predicate = isFlattenable);
  result || (result = []);

  while (++index < length) {
    var value = array[index];
    if (depth > 0 && predicate(value)) {
      if (depth > 1) {
        // Recursively flatten arrays (susceptible to call stack limits).
        baseFlatten(value, depth - 1, predicate, isStrict, result);
      } else {
        arrayPush(result, value);
      }
    } else if (!isStrict) {
      result[result.length] = value;
    }
  }
  return result;
}

/**
 * Flattens `array` a single level deep.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to flatten.
 * @returns {Array} Returns the new flattened array.
 * @example
 *
 * _.flatten([1, [2, [3, [4]], 5]]);
 * // => [1, 2, [3, [4]], 5]
 */
function flatten(array) {
  var length = array == null ? 0 : array.length;
  return length ? baseFlatten(array, 1) : [];
}

/**
 * A faster alternative to `Function#apply`, this function invokes `func`
 * with the `this` binding of `thisArg` and the arguments of `args`.
 *
 * @private
 * @param {Function} func The function to invoke.
 * @param {*} thisArg The `this` binding of `func`.
 * @param {Array} args The arguments to invoke `func` with.
 * @returns {*} Returns the result of `func`.
 */
function apply(func, thisArg, args) {
  switch (args.length) {
    case 0: return func.call(thisArg);
    case 1: return func.call(thisArg, args[0]);
    case 2: return func.call(thisArg, args[0], args[1]);
    case 3: return func.call(thisArg, args[0], args[1], args[2]);
  }
  return func.apply(thisArg, args);
}

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax$1 = Math.max;

/**
 * A specialized version of `baseRest` which transforms the rest array.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @param {number} [start=func.length-1] The start position of the rest parameter.
 * @param {Function} transform The rest array transform.
 * @returns {Function} Returns the new function.
 */
function overRest(func, start, transform) {
  start = nativeMax$1(start === undefined ? (func.length - 1) : start, 0);
  return function() {
    var args = arguments,
        index = -1,
        length = nativeMax$1(args.length - start, 0),
        array = Array(length);

    while (++index < length) {
      array[index] = args[start + index];
    }
    index = -1;
    var otherArgs = Array(start + 1);
    while (++index < start) {
      otherArgs[index] = args[index];
    }
    otherArgs[start] = transform(array);
    return apply(func, this, otherArgs);
  };
}

/**
 * Creates a function that returns `value`.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {*} value The value to return from the new function.
 * @returns {Function} Returns the new constant function.
 * @example
 *
 * var objects = _.times(2, _.constant({ 'a': 1 }));
 *
 * console.log(objects);
 * // => [{ 'a': 1 }, { 'a': 1 }]
 *
 * console.log(objects[0] === objects[1]);
 * // => true
 */
function constant(value) {
  return function() {
    return value;
  };
}

/**
 * This method returns the first argument it receives.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Util
 * @param {*} value Any value.
 * @returns {*} Returns `value`.
 * @example
 *
 * var object = { 'a': 1 };
 *
 * console.log(_.identity(object) === object);
 * // => true
 */
function identity(value) {
  return value;
}

/**
 * The base implementation of `setToString` without support for hot loop shorting.
 *
 * @private
 * @param {Function} func The function to modify.
 * @param {Function} string The `toString` result.
 * @returns {Function} Returns `func`.
 */
var baseSetToString = !defineProperty ? identity : function(func, string) {
  return defineProperty(func, 'toString', {
    'configurable': true,
    'enumerable': false,
    'value': constant(string),
    'writable': true
  });
};

/** Used to detect hot functions by number of calls within a span of milliseconds. */
var HOT_COUNT = 800,
    HOT_SPAN = 16;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeNow = Date.now;

/**
 * Creates a function that'll short out and invoke `identity` instead
 * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
 * milliseconds.
 *
 * @private
 * @param {Function} func The function to restrict.
 * @returns {Function} Returns the new shortable function.
 */
function shortOut(func) {
  var count = 0,
      lastCalled = 0;

  return function() {
    var stamp = nativeNow(),
        remaining = HOT_SPAN - (stamp - lastCalled);

    lastCalled = stamp;
    if (remaining > 0) {
      if (++count >= HOT_COUNT) {
        return arguments[0];
      }
    } else {
      count = 0;
    }
    return func.apply(undefined, arguments);
  };
}

/**
 * Sets the `toString` method of `func` to return `string`.
 *
 * @private
 * @param {Function} func The function to modify.
 * @param {Function} string The `toString` result.
 * @returns {Function} Returns `func`.
 */
var setToString = shortOut(baseSetToString);

/**
 * A specialized version of `baseRest` which flattens the rest array.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @returns {Function} Returns the new function.
 */
function flatRest(func) {
  return setToString(overRest(func, undefined, flatten), func + '');
}

/** Used to compose bitmasks for cloning. */
var CLONE_DEEP_FLAG$1 = 1,
    CLONE_FLAT_FLAG$1 = 2,
    CLONE_SYMBOLS_FLAG$1 = 4;

/**
 * The opposite of `_.pick`; this method creates an object composed of the
 * own and inherited enumerable property paths of `object` that are not omitted.
 *
 * **Note:** This method is considerably slower than `_.pick`.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The source object.
 * @param {...(string|string[])} [paths] The property paths to omit.
 * @returns {Object} Returns the new object.
 * @example
 *
 * var object = { 'a': 1, 'b': '2', 'c': 3 };
 *
 * _.omit(object, ['a', 'c']);
 * // => { 'b': '2' }
 */
var omit = flatRest(function(object, paths) {
  var result = {};
  if (object == null) {
    return result;
  }
  var isDeep = false;
  paths = arrayMap(paths, function(path) {
    path = castPath(path, object);
    isDeep || (isDeep = path.length > 1);
    return path;
  });
  copyObject(object, getAllKeysIn(object), result);
  if (isDeep) {
    result = baseClone(result, CLONE_DEEP_FLAG$1 | CLONE_FLAT_FLAG$1 | CLONE_SYMBOLS_FLAG$1, customOmitClone);
  }
  var length = paths.length;
  while (length--) {
    baseUnset(result, paths[length]);
  }
  return result;
});

var isPromise = function (thing) {
    return typeof thing.then === 'function';
};
var isRequestInfo = function (thing) { return !isPromise(thing); };
var BuilderAsyncRequestsContext = React.createContext({
    requests: [],
    errors: [],
    logs: [],
});

var fnCache = {};
function stringToFunction(str, expression, errors, logs) {
    if (expression === void 0) { expression = true; }
    if (!str || !str.trim()) {
        return function () { return undefined; };
    }
    var cacheKey = str + ':' + expression;
    if (fnCache[cacheKey]) {
        return fnCache[cacheKey];
    }
    // FIXME: gross hack
    var useReturn = (expression &&
        !(str.includes(';') || str.includes(' return ') || str.trim().startsWith('return '))) ||
        str.trim().startsWith('builder.run');
    var fn = function () {
        /* intentionally empty */
    };
    try {
        // tslint:disable-next-line:no-function-constructor-with-string-args
        // TODO: use strict and eval
        fn = new Function('state', 'event', 'block', 'builder', 'Device', 'update', 
        // TODO: block reference...
        // TODO: or just remove with (rootState) in general
        "\n          var rootState = state;\n          if (typeof Proxy !== 'undefined') {\n            rootState = new Proxy(rootState, {\n              set: function () {\n                return false;\n              }\n            });\n          }\n          with (rootState) {\n            " + (useReturn ? "return (" + str + ");" : str) + ";\n          }\n        ");
    }
    catch (error) {
        if (errors) {
            errors.push(error);
        }
        var message = error && error.message;
        if (message && typeof message === 'string') {
            if (logs && logs.indexOf(message) === -1) {
                logs.push(message);
            }
        }
        console.warn("Function compile error in " + str, error);
    }
    var final = (fnCache[cacheKey] = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        try {
            return fn.apply(void 0, args);
        }
        catch (error) {
            console.warn('Builder custom code error:', error.message, error.stack);
            if (errors) {
                errors.push(error);
            }
        }
    });
    return final;
}

var Device = { desktop: 0, tablet: 1, mobile: 2 };
// TODO: pull from builer internal utils
var fastClone = function (obj) { return JSON.parse(JSON.stringify(obj)); };
function capitalize(str) {
    if (!str) {
        return;
    }
    return str[0].toUpperCase() + str.slice(1);
}
var BuilderBlock = /** @class */ (function (_super) {
    __extends(BuilderBlock, _super);
    function BuilderBlock() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.privateState = {
            state: {},
            update: function () {
                /* Intentionally empty */
            },
        };
        return _this;
    }
    // TODO: handle adding return if none provided
    // TODO: cache/memoize this (globally with LRU?)
    BuilderBlock.prototype.stringToFunction = function (str, expression) {
        if (expression === void 0) { expression = true; }
        return stringToFunction(str, expression, this._errors, this._logs);
    };
    Object.defineProperty(BuilderBlock.prototype, "styles", {
        get: function () {
            // TODO: handle style bindings
            var _a = this.props, block = _a.block, size = _a.size;
            if (!size) {
                // TODO: use device size API for this
                size = 'small';
            }
            var styles = [];
            var startIndex = 0; // sizeNames.indexOf(size || 'large');
            if (block.responsiveStyles) {
                for (var i = startIndex; i < sizeNames.length; i = i + 1) {
                    var name_1 = sizeNames[i];
                    if (block.responsiveStyles[name_1]) {
                        styles.push(block.responsiveStyles[name_1]);
                    }
                }
            }
            // TODO: animations
            var finalStyleObject = Object.assign.apply(Object, __spreadArrays([{}], styles.reverse()));
            for (var key in finalStyleObject) {
                var value = finalStyleObject[key];
                if (typeof value === 'string') {
                    var matched = value.trim().match(/^([\d\.]+)(px)?$/);
                    if (matched) {
                        finalStyleObject[key] = parseFloat(matched[1]);
                    }
                    if (value.includes('calc(')) {
                        // console.warn('calc not supported');
                        delete finalStyleObject[key];
                    }
                    if (value.includes('vw')) {
                        // console.warn('calc not supported');
                        delete finalStyleObject[key];
                    }
                }
            }
            // TODO: convert transform string to array/object form for react native with regex
            return omit(finalStyleObject, 'boxSizing', 'transform');
        },
        enumerable: true,
        configurable: true
    });
    BuilderBlock.prototype.componentDidMount = function () {
        var block = this.props.block;
        var animations = block && block.animations;
        // tslint:disable-next-line:comment-format
        ///REACT15ONLY if (this.ref) { this.ref.setAttribute('builder-id', block.id); }
        if (animations) {
            var options = {
                animations: fastClone(animations),
            };
            // TODO: listen to Builder.editingMode and bind animations when editing
            // and unbind when not
            // TODO: apply bindings first
            if (block.bindings) {
                for (var key in block.bindings) {
                    if (key.startsWith('animations.')) {
                        var value = this.stringToFunction(block.bindings[key]);
                        if (value !== undefined) {
                            set(options, key, value(this.privateState.state));
                        }
                    }
                }
            }
            // TODO: animations
        }
    };
    // <!-- Builder Blocks --> in comments hmm
    BuilderBlock.prototype.getElement = function (index, state) {
        var _this = this;
        if (index === void 0) { index = 0; }
        if (state === void 0) { state = this.privateState.state; }
        var _a = this.props, block = _a.block, child = _a.child, fieldName = _a.fieldName;
        var TagName = View; //  (block.tagName || 'div').toLowerCase();
        if (block.actions && block.actions.click) ;
        var InnerComponent;
        var componentName = block.component && (block.component.name || block.component.component);
        var componentInfo = null;
        if (block.component && !block.component.class) {
            if (block.component && block.component.tag) {
                InnerComponent = block.component.tag;
            }
            else {
                componentInfo = Builder.components.find(function (item) { return item.name === componentName; }) || null;
                if (componentInfo && componentInfo.class) {
                    InnerComponent = componentInfo.class;
                }
                else if (componentInfo && componentInfo.tag) {
                    InnerComponent = componentInfo.tag;
                }
            }
        }
        var isBlock = !includes(['absolute', 'fixed'], block.responsiveStyles &&
            block.responsiveStyles.large &&
            block.responsiveStyles.large.position /*( this.styles.position */);
        var options = __assign(__assign({}, block.properties), { style: {} });
        options = __assign(__assign({}, options.properties), options);
        if (block.component) {
            options.component = fastClone(block.component);
        }
        // Binding should be properties to href or href?
        // Manual style editor show bindings
        // Show if things bound in overlays hmm
        if (block.bindings) {
            for (var key in block.bindings) {
                var value = this.stringToFunction(block.bindings[key]);
                // TODO: pass block, etc
                set(options, key, value(state, null, block, {}, Device));
            }
        }
        if (options.hide) {
            return null;
        }
        var latestState = state;
        if (block.actions) {
            var _loop_1 = function (key) {
                var value = block.actions[key];
                if (key === 'click') {
                    key = 'press';
                }
                options['on' + capitalize(key)] = function (event) {
                    var update = function (cb) {
                        _this.privateState.update(function (globalState) {
                            latestState = globalState;
                            var localState = globalState;
                            if (typeof Proxy !== 'undefined') {
                                localState = new Proxy(__assign({}, globalState), {
                                    getOwnPropertyDescriptor: function (target, property) {
                                        try {
                                            return Reflect.getOwnPropertyDescriptor(latestState, property);
                                        }
                                        catch (error) {
                                            return undefined;
                                        }
                                    },
                                    // TODO: wrap other proxy properties
                                    set: function (target, key, value) {
                                        // TODO: do these for deep sets from references hmm
                                        return Reflect.set(latestState, key, value);
                                        // return false;
                                    },
                                    // to prevent variable doesn't exist errors with `with (state)`
                                    has: function (target, property) {
                                        try {
                                            // TODO: if dead trigger an immer update
                                            return Reflect.has(latestState, property);
                                        }
                                        catch (error) {
                                            return false;
                                        }
                                    },
                                    get: function (object, property) {
                                        if (property &&
                                            typeof property === 'string' &&
                                            property.endsWith('Item') &&
                                            !Reflect.has(latestState, property)) {
                                            // TODO: use $index to return a reference to the proxied version of item
                                            // so can be set as well
                                            return Reflect.get(state, property);
                                        }
                                        return Reflect.get(latestState, property);
                                    },
                                });
                            }
                            return cb(localState, event, undefined, {}, Device, update);
                        });
                    };
                    var fn = _this.stringToFunction(value, false);
                    update(fn);
                };
            };
            for (var key in block.actions) {
                _loop_1(key);
            }
        }
        var innerComponentProperties = (options.component || options.options) && __assign(__assign({}, options.options), (options.component.options || options.component.data));
        var noWrap = componentInfo && (componentInfo.fragment || componentInfo.noWrap);
        var finalOptions = __assign(__assign(__assign({}, omit(options, 'class', 'component')), { style: this.styles, class: "builder-block " + this.id + (block.class ? " " + block.class : '') + (block.component && !includes(['Image', 'Video', 'Banner'], componentName)
                ? " builder-has-component"
                : '') + (options.class ? ' ' + options.class : ''), key: this.id + index, 
            // Remove for amp mode
            'builder-id': this.id }), (index !== 0 && {
            'builder-index': index,
        }));
        var children = block.children || finalOptions.children || [];
        // TODO: test it out
        return (React.createElement(BuilderAsyncRequestsContext.Consumer, null, function (value) {
            _this._errors = value && value.errors;
            _this._logs = value && value.logs;
            return  InnerComponent && (noWrap || _this.props.emailMode) ? (
            // TODO: pass the class to be easier
            // TODO: acceptsChildren option?
            React.createElement(React.Fragment, null,
                React.createElement(InnerComponent
                // Final options maaay be wrong here hm
                , __assign({}, innerComponentProperties, { attributes: finalOptions, builderBlock: block })))) : (React.createElement(TagName, __assign({}, finalOptions),
                InnerComponent && (React.createElement(InnerComponent, __assign({ builderBlock: block }, innerComponentProperties))),
                !InnerComponent && children && children.length
                    ? children.map(function (block, index) { return (React.createElement(BuilderBlock, { key: (_this.id || '') + index, block: block, index: index, size: _this.props.size, fieldName: _this.props.fieldName, child: _this.props.child, emailMode: _this.props.emailMode })); })
                    : null));
        }));
    };
    Object.defineProperty(BuilderBlock.prototype, "id", {
        get: function () {
            var block = this.props.block;
            if (!block.id.startsWith('builder')) {
                return 'builder-' + block.id;
            }
            return block.id;
        },
        enumerable: true,
        configurable: true
    });
    BuilderBlock.prototype.contents = function (state) {
        var _this = this;
        var block = this.props.block;
        // this.setState(state);
        this.privateState = state;
        if (block.repeat && block.repeat.collection) {
            var collectionPath = block.repeat.collection;
            var collectionName = last((collectionPath || '').trim().split('(')[0].trim().split('.'));
            var itemName_1 = block.repeat.itemName || (collectionName ? collectionName + 'Item' : 'item');
            var array = this.stringToFunction(collectionPath)(state.state, null, block, {}, Device);
            if (isArray(array)) {
                return array.map(function (data, index) {
                    var _a;
                    // TODO: Builder state produce the data
                    var childState = __assign(__assign({}, state.state), (_a = { $index: index, $item: data }, _a[itemName_1] = data, _a));
                    return (React.createElement(BuilderStoreContext.Provider, { key: index, value: __assign(__assign({}, state), { state: childState }) }, _this.getElement(index, childState)));
                });
            }
            return null;
        }
        return this.getElement();
    };
    BuilderBlock.prototype.render = function () {
        var _this = this;
        return (React.createElement(BuilderStoreContext.Consumer, null, function (value) { return _this.contents(value); }));
    };
    return BuilderBlock;
}(React.Component));

// TODO: options to set direciotn
var BuilderBlocks = /** @class */ (function (_super) {
    __extends(BuilderBlocks, _super);
    function BuilderBlocks() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onClickEmptyBlocks = function () {
            if (Builder.isIframe && _this.noBlocks) {
                window.parent.postMessage({
                    type: 'builder.clickEmptyBlocks',
                    data: {
                        parentElementId: _this.parentId,
                        dataPath: _this.path,
                    },
                }, '*');
            }
        };
        return _this;
    }
    Object.defineProperty(BuilderBlocks.prototype, "isRoot", {
        get: function () {
            return !this.props.child;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderBlocks.prototype, "noBlocks", {
        get: function () {
            var blocks = this.props.blocks;
            return !(blocks && blocks.length); // TODO: allow react nodes
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderBlocks.prototype, "path", {
        get: function () {
            var pathPrefix = 'component.options.';
            var path = this.props.dataPath || 'children';
            var thisPrefix = 'this.';
            if (path.trim()) {
                if (path.startsWith(thisPrefix)) {
                    path = path.replace(thisPrefix, '');
                }
                else if (!path.startsWith(pathPrefix)) {
                    path = pathPrefix + path;
                }
            }
            return path;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderBlocks.prototype, "parentId", {
        get: function () {
            if (this.props.parentElementId) {
                return this.props.parentElementId;
            }
            return this.props.parent && this.props.parent.id;
        },
        enumerable: true,
        configurable: true
    });
    // <!-- Builder Blocks --> in comments hmm
    BuilderBlocks.prototype.render = function () {
        var _this = this;
        var blocks = this.props.blocks;
        // TODO: how deep check this automatically for mobx... hmmm optional / peer dependency?
        return (
        // TODO: component <Stack direction="vertical">
        // TODO: react.fragment instead?
        React.createElement(View, { style: __assign({}, this.props.style) }, (blocks &&
            Array.isArray(blocks) &&
            blocks.map(function (block, index) {
                return block && block['@type'] === '@builder.io/sdk:Element' ? (React.createElement(BuilderBlock, { key: block.id, block: block, index: index, fieldName: _this.props.fieldName, child: _this.props.child, emailMode: _this.props.emailMode })) : (block);
            })) ||
            blocks));
    };
    return BuilderBlocks;
}(React.Component));

var BuilderContent = /** @class */ (function (_super) {
    __extends(BuilderContent, _super);
    function BuilderContent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            loading: true,
            data: null,
        };
        _this.subscriptions = new Subscription();
        _this.firstLoad = true;
        _this.clicked = false;
        _this.trackedImpression = false;
        _this.onClick = function (reactEvent) {
            // TODO: viewport scrolling tracking for impression events
            var event = reactEvent.nativeEvent;
            var content = _this.state.data;
            if (!content) {
                return;
            }
            if (builder.autoTrack) ;
            if (!_this.clicked) {
                _this.clicked = true;
            }
        };
        return _this;
    }
    // TODO: observe model name for changes
    BuilderContent.prototype.componentDidMount = function () {
        // Temporary to test metrics diving in with bigquery and heatmaps
        // builder.autoTrack = true;
        // builder.env = 'development';
        this.subscribeToContent();
        ///REACT15ONLY if (this.ref) { this.ref.setAttribute('builder-model', this.props.modelName); }
    };
    BuilderContent.prototype.subscribeToContent = function () {
        var _this = this;
        if (this.props.modelName !== '_inline') {
            // TODO:... using targeting...? express.request hmmm
            this.subscriptions.add(builder.queueGetContent(this.props.modelName, this.props.options).subscribe(function (matches) {
                var match = matches && matches[0];
                _this.setState({
                    data: match,
                });
                if (match && _this.firstLoad) {
                    // TODO: autoTrack
                    if (builder.autoTrack) {
                        _this.trackedImpression = true;
                        builder.trackImpression(match.id, match.variationId, undefined, {
                            content: match,
                        });
                    }
                    _this.firstLoad = false;
                }
                if (_this.props.contentLoaded) {
                    _this.props.contentLoaded((match && match.data) || null);
                }
            }, function (error) {
                if (_this.props.contentError) {
                    _this.props.contentError(error);
                }
            }));
        }
    };
    BuilderContent.prototype.componentWillUnmount = function () {
        this.subscriptions.unsubscribe();
    };
    BuilderContent.prototype.render = function () {
        var _a = this.state, data = _a.data, loading = _a.loading;
        // TODO: why is this server only? any time there is initial content
        // use it no?
        //
        var useData = ((this.props.inline || !Builder.isBrowser) &&
            this.props.options &&
            this.props.options.initialContent &&
            this.props.options.initialContent[0]) ||
            data;
        return (
        // TODO: use fragment
        // <TouchableWithoutFeedback
        React.createElement(View
        // ref={ref => (this.ref = ref)}
        // onPress={this.onClick}
        , { "builder-content-id": useData && useData.id, "builder-model": this.props.modelName }, this.props.children(useData && useData.data, loading, useData)));
    };
    return BuilderContent;
}(React.Component));

/**
 * The base implementation of  `_.pickBy` without support for iteratee shorthands.
 *
 * @private
 * @param {Object} object The source object.
 * @param {string[]} paths The property paths to pick.
 * @param {Function} predicate The function invoked per property.
 * @returns {Object} Returns the new object.
 */
function basePickBy(object, paths, predicate) {
  var index = -1,
      length = paths.length,
      result = {};

  while (++index < length) {
    var path = paths[index],
        value = baseGet(object, path);

    if (predicate(value, path)) {
      baseSet(result, castPath(path, object), value);
    }
  }
  return result;
}

/**
 * The base implementation of `_.hasIn` without support for deep paths.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {Array|string} key The key to check.
 * @returns {boolean} Returns `true` if `key` exists, else `false`.
 */
function baseHasIn(object, key) {
  return object != null && key in Object(object);
}

/**
 * Checks if `path` exists on `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @param {Function} hasFunc The function to check properties.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 */
function hasPath(object, path, hasFunc) {
  path = castPath(path, object);

  var index = -1,
      length = path.length,
      result = false;

  while (++index < length) {
    var key = toKey(path[index]);
    if (!(result = object != null && hasFunc(object, key))) {
      break;
    }
    object = object[key];
  }
  if (result || ++index != length) {
    return result;
  }
  length = object == null ? 0 : object.length;
  return !!length && isLength(length) && isIndex(key, length) &&
    (isArray(object) || isArguments(object));
}

/**
 * Checks if `path` is a direct or inherited property of `object`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Object
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 * @example
 *
 * var object = _.create({ 'a': _.create({ 'b': 2 }) });
 *
 * _.hasIn(object, 'a');
 * // => true
 *
 * _.hasIn(object, 'a.b');
 * // => true
 *
 * _.hasIn(object, ['a', 'b']);
 * // => true
 *
 * _.hasIn(object, 'b');
 * // => false
 */
function hasIn(object, path) {
  return object != null && hasPath(object, path, baseHasIn);
}

/**
 * The base implementation of `_.pick` without support for individual
 * property identifiers.
 *
 * @private
 * @param {Object} object The source object.
 * @param {string[]} paths The property paths to pick.
 * @returns {Object} Returns the new object.
 */
function basePick(object, paths) {
  return basePickBy(object, paths, function(value, path) {
    return hasIn(object, path);
  });
}

/**
 * Creates an object composed of the picked `object` properties.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The source object.
 * @param {...(string|string[])} [paths] The property paths to pick.
 * @returns {Object} Returns the new object.
 * @example
 *
 * var object = { 'a': 1, 'b': '2', 'c': 3 };
 *
 * _.pick(object, ['a', 'c']);
 * // => { 'a': 1, 'c': 3 }
 */
var pick = flatRest(function(object, paths) {
  return object == null ? {} : basePick(object, paths);
});

/**
 * Gets the timestamp of the number of milliseconds that have elapsed since
 * the Unix epoch (1 January 1970 00:00:00 UTC).
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Date
 * @returns {number} Returns the timestamp.
 * @example
 *
 * _.defer(function(stamp) {
 *   console.log(_.now() - stamp);
 * }, _.now());
 * // => Logs the number of milliseconds it took for the deferred invocation.
 */
var now = function() {
  return root.Date.now();
};

/** Error message constants. */
var FUNC_ERROR_TEXT$1 = 'Expected a function';

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax$2 = Math.max,
    nativeMin = Math.min;

/**
 * Creates a debounced function that delays invoking `func` until after `wait`
 * milliseconds have elapsed since the last time the debounced function was
 * invoked. The debounced function comes with a `cancel` method to cancel
 * delayed `func` invocations and a `flush` method to immediately invoke them.
 * Provide `options` to indicate whether `func` should be invoked on the
 * leading and/or trailing edge of the `wait` timeout. The `func` is invoked
 * with the last arguments provided to the debounced function. Subsequent
 * calls to the debounced function return the result of the last `func`
 * invocation.
 *
 * **Note:** If `leading` and `trailing` options are `true`, `func` is
 * invoked on the trailing edge of the timeout only if the debounced function
 * is invoked more than once during the `wait` timeout.
 *
 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
 *
 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
 * for details over the differences between `_.debounce` and `_.throttle`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to debounce.
 * @param {number} [wait=0] The number of milliseconds to delay.
 * @param {Object} [options={}] The options object.
 * @param {boolean} [options.leading=false]
 *  Specify invoking on the leading edge of the timeout.
 * @param {number} [options.maxWait]
 *  The maximum time `func` is allowed to be delayed before it's invoked.
 * @param {boolean} [options.trailing=true]
 *  Specify invoking on the trailing edge of the timeout.
 * @returns {Function} Returns the new debounced function.
 * @example
 *
 * // Avoid costly calculations while the window size is in flux.
 * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
 *
 * // Invoke `sendMail` when clicked, debouncing subsequent calls.
 * jQuery(element).on('click', _.debounce(sendMail, 300, {
 *   'leading': true,
 *   'trailing': false
 * }));
 *
 * // Ensure `batchLog` is invoked once after 1 second of debounced calls.
 * var debounced = _.debounce(batchLog, 250, { 'maxWait': 1000 });
 * var source = new EventSource('/stream');
 * jQuery(source).on('message', debounced);
 *
 * // Cancel the trailing debounced invocation.
 * jQuery(window).on('popstate', debounced.cancel);
 */
function debounce(func, wait, options) {
  var lastArgs,
      lastThis,
      maxWait,
      result,
      timerId,
      lastCallTime,
      lastInvokeTime = 0,
      leading = false,
      maxing = false,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT$1);
  }
  wait = toNumber(wait) || 0;
  if (isObject(options)) {
    leading = !!options.leading;
    maxing = 'maxWait' in options;
    maxWait = maxing ? nativeMax$2(toNumber(options.maxWait) || 0, wait) : maxWait;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }

  function invokeFunc(time) {
    var args = lastArgs,
        thisArg = lastThis;

    lastArgs = lastThis = undefined;
    lastInvokeTime = time;
    result = func.apply(thisArg, args);
    return result;
  }

  function leadingEdge(time) {
    // Reset any `maxWait` timer.
    lastInvokeTime = time;
    // Start the timer for the trailing edge.
    timerId = setTimeout(timerExpired, wait);
    // Invoke the leading edge.
    return leading ? invokeFunc(time) : result;
  }

  function remainingWait(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime,
        timeWaiting = wait - timeSinceLastCall;

    return maxing
      ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke)
      : timeWaiting;
  }

  function shouldInvoke(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime;

    // Either this is the first call, activity has stopped and we're at the
    // trailing edge, the system time has gone backwards and we're treating
    // it as the trailing edge, or we've hit the `maxWait` limit.
    return (lastCallTime === undefined || (timeSinceLastCall >= wait) ||
      (timeSinceLastCall < 0) || (maxing && timeSinceLastInvoke >= maxWait));
  }

  function timerExpired() {
    var time = now();
    if (shouldInvoke(time)) {
      return trailingEdge(time);
    }
    // Restart the timer.
    timerId = setTimeout(timerExpired, remainingWait(time));
  }

  function trailingEdge(time) {
    timerId = undefined;

    // Only invoke if we have `lastArgs` which means `func` has been
    // debounced at least once.
    if (trailing && lastArgs) {
      return invokeFunc(time);
    }
    lastArgs = lastThis = undefined;
    return result;
  }

  function cancel() {
    if (timerId !== undefined) {
      clearTimeout(timerId);
    }
    lastInvokeTime = 0;
    lastArgs = lastCallTime = lastThis = timerId = undefined;
  }

  function flush() {
    return timerId === undefined ? result : trailingEdge(now());
  }

  function debounced() {
    var time = now(),
        isInvoking = shouldInvoke(time);

    lastArgs = arguments;
    lastThis = this;
    lastCallTime = time;

    if (isInvoking) {
      if (timerId === undefined) {
        return leadingEdge(lastCallTime);
      }
      if (maxing) {
        // Handle invocations in a tight loop.
        clearTimeout(timerId);
        timerId = setTimeout(timerExpired, wait);
        return invokeFunc(lastCallTime);
      }
    }
    if (timerId === undefined) {
      timerId = setTimeout(timerExpired, wait);
    }
    return result;
  }
  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
}

/** Error message constants. */
var FUNC_ERROR_TEXT$2 = 'Expected a function';

/**
 * Creates a throttled function that only invokes `func` at most once per
 * every `wait` milliseconds. The throttled function comes with a `cancel`
 * method to cancel delayed `func` invocations and a `flush` method to
 * immediately invoke them. Provide `options` to indicate whether `func`
 * should be invoked on the leading and/or trailing edge of the `wait`
 * timeout. The `func` is invoked with the last arguments provided to the
 * throttled function. Subsequent calls to the throttled function return the
 * result of the last `func` invocation.
 *
 * **Note:** If `leading` and `trailing` options are `true`, `func` is
 * invoked on the trailing edge of the timeout only if the throttled function
 * is invoked more than once during the `wait` timeout.
 *
 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
 *
 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
 * for details over the differences between `_.throttle` and `_.debounce`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to throttle.
 * @param {number} [wait=0] The number of milliseconds to throttle invocations to.
 * @param {Object} [options={}] The options object.
 * @param {boolean} [options.leading=true]
 *  Specify invoking on the leading edge of the timeout.
 * @param {boolean} [options.trailing=true]
 *  Specify invoking on the trailing edge of the timeout.
 * @returns {Function} Returns the new throttled function.
 * @example
 *
 * // Avoid excessively updating the position while scrolling.
 * jQuery(window).on('scroll', _.throttle(updatePosition, 100));
 *
 * // Invoke `renewToken` when the click event is fired, but not more than once every 5 minutes.
 * var throttled = _.throttle(renewToken, 300000, { 'trailing': false });
 * jQuery(element).on('click', throttled);
 *
 * // Cancel the trailing throttled invocation.
 * jQuery(window).on('popstate', throttled.cancel);
 */
function throttle(func, wait, options) {
  var leading = true,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT$2);
  }
  if (isObject(options)) {
    leading = 'leading' in options ? !!options.leading : leading;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }
  return debounce(func, wait, {
    'leading': leading,
    'maxWait': wait,
    'trailing': trailing
  });
}

/**
 * The base implementation of `_.property` without support for deep paths.
 *
 * @private
 * @param {string} key The key of the property to get.
 * @returns {Function} Returns the new accessor function.
 */
function baseProperty(key) {
  return function(object) {
    return object == null ? undefined : object[key];
  };
}

/**
 * Gets the size of an ASCII `string`.
 *
 * @private
 * @param {string} string The string inspect.
 * @returns {number} Returns the string size.
 */
var asciiSize = baseProperty('length');

/** Used to compose unicode character classes. */
var rsAstralRange = '\\ud800-\\udfff',
    rsComboMarksRange = '\\u0300-\\u036f',
    reComboHalfMarksRange = '\\ufe20-\\ufe2f',
    rsComboSymbolsRange = '\\u20d0-\\u20ff',
    rsComboRange = rsComboMarksRange + reComboHalfMarksRange + rsComboSymbolsRange,
    rsVarRange = '\\ufe0e\\ufe0f';

/** Used to compose unicode capture groups. */
var rsZWJ = '\\u200d';

/** Used to detect strings with [zero-width joiners or code points from the astral planes](http://eev.ee/blog/2015/09/12/dark-corners-of-unicode/). */
var reHasUnicode = RegExp('[' + rsZWJ + rsAstralRange  + rsComboRange + rsVarRange + ']');

/**
 * Checks if `string` contains Unicode symbols.
 *
 * @private
 * @param {string} string The string to inspect.
 * @returns {boolean} Returns `true` if a symbol is found, else `false`.
 */
function hasUnicode(string) {
  return reHasUnicode.test(string);
}

/** Used to compose unicode character classes. */
var rsAstralRange$1 = '\\ud800-\\udfff',
    rsComboMarksRange$1 = '\\u0300-\\u036f',
    reComboHalfMarksRange$1 = '\\ufe20-\\ufe2f',
    rsComboSymbolsRange$1 = '\\u20d0-\\u20ff',
    rsComboRange$1 = rsComboMarksRange$1 + reComboHalfMarksRange$1 + rsComboSymbolsRange$1,
    rsVarRange$1 = '\\ufe0e\\ufe0f';

/** Used to compose unicode capture groups. */
var rsAstral = '[' + rsAstralRange$1 + ']',
    rsCombo = '[' + rsComboRange$1 + ']',
    rsFitz = '\\ud83c[\\udffb-\\udfff]',
    rsModifier = '(?:' + rsCombo + '|' + rsFitz + ')',
    rsNonAstral = '[^' + rsAstralRange$1 + ']',
    rsRegional = '(?:\\ud83c[\\udde6-\\uddff]){2}',
    rsSurrPair = '[\\ud800-\\udbff][\\udc00-\\udfff]',
    rsZWJ$1 = '\\u200d';

/** Used to compose unicode regexes. */
var reOptMod = rsModifier + '?',
    rsOptVar = '[' + rsVarRange$1 + ']?',
    rsOptJoin = '(?:' + rsZWJ$1 + '(?:' + [rsNonAstral, rsRegional, rsSurrPair].join('|') + ')' + rsOptVar + reOptMod + ')*',
    rsSeq = rsOptVar + reOptMod + rsOptJoin,
    rsSymbol = '(?:' + [rsNonAstral + rsCombo + '?', rsCombo, rsRegional, rsSurrPair, rsAstral].join('|') + ')';

/** Used to match [string symbols](https://mathiasbynens.be/notes/javascript-unicode). */
var reUnicode = RegExp(rsFitz + '(?=' + rsFitz + ')|' + rsSymbol + rsSeq, 'g');

/**
 * Gets the size of a Unicode `string`.
 *
 * @private
 * @param {string} string The string inspect.
 * @returns {number} Returns the string size.
 */
function unicodeSize(string) {
  var result = reUnicode.lastIndex = 0;
  while (reUnicode.test(string)) {
    ++result;
  }
  return result;
}

/**
 * Gets the number of symbols in `string`.
 *
 * @private
 * @param {string} string The string to inspect.
 * @returns {number} Returns the string size.
 */
function stringSize(string) {
  return hasUnicode(string)
    ? unicodeSize(string)
    : asciiSize(string);
}

/** `Object#toString` result references. */
var mapTag$5 = '[object Map]',
    setTag$5 = '[object Set]';

/**
 * Gets the size of `collection` by returning its length for array-like
 * values or the number of own enumerable string keyed properties for objects.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Collection
 * @param {Array|Object|string} collection The collection to inspect.
 * @returns {number} Returns the collection size.
 * @example
 *
 * _.size([1, 2, 3]);
 * // => 3
 *
 * _.size({ 'a': 1, 'b': 2 });
 * // => 2
 *
 * _.size('pebbles');
 * // => 7
 */
function size(collection) {
  if (collection == null) {
    return 0;
  }
  if (isArrayLike(collection)) {
    return isString(collection) ? stringSize(collection) : collection.length;
  }
  var tag = getTag$1(collection);
  if (tag == mapTag$5 || tag == setTag$5) {
    return collection.size;
  }
  return baseKeys(collection).length;
}

/**
 * The base implementation of `_.rest` which doesn't validate or coerce arguments.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @param {number} [start=func.length-1] The start position of the rest parameter.
 * @returns {Function} Returns the new function.
 */
function baseRest(func, start) {
  return setToString(overRest(func, start, identity), func + '');
}

/** `Object#toString` result references. */
var domExcTag = '[object DOMException]',
    errorTag$2 = '[object Error]';

/**
 * Checks if `value` is an `Error`, `EvalError`, `RangeError`, `ReferenceError`,
 * `SyntaxError`, `TypeError`, or `URIError` object.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an error object, else `false`.
 * @example
 *
 * _.isError(new Error);
 * // => true
 *
 * _.isError(Error);
 * // => false
 */
function isError(value) {
  if (!isObjectLike(value)) {
    return false;
  }
  var tag = baseGetTag(value);
  return tag == errorTag$2 || tag == domExcTag ||
    (typeof value.message == 'string' && typeof value.name == 'string' && !isPlainObject(value));
}

/**
 * Attempts to invoke `func`, returning either the result or the caught error
 * object. Any additional arguments are provided to `func` when it's invoked.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Util
 * @param {Function} func The function to attempt.
 * @param {...*} [args] The arguments to invoke `func` with.
 * @returns {*} Returns the `func` result or error object.
 * @example
 *
 * // Avoid throwing errors for invalid selectors.
 * var elements = _.attempt(function(selector) {
 *   return document.querySelectorAll(selector);
 * }, '>_>');
 *
 * if (_.isError(elements)) {
 *   elements = [];
 * }
 */
var attempt = baseRest(function(func, args) {
  try {
    return apply(func, undefined, args);
  } catch (e) {
    return isError(e) ? e : new Error(e);
  }
});

var nextTick = Builder.nextTick;
function debounceNextTick(target, key, descriptor) {
    if (typeof key === 'undefined' && typeof target === 'function') {
        return debounceNextTickImpl(target);
    }
    return {
        configurable: true,
        enumerable: descriptor.enumerable,
        get: function getter() {
            // Attach this function to the instance (not the class)
            Object.defineProperty(this, key, {
                configurable: true,
                enumerable: descriptor.enumerable,
                value: debounceNextTickImpl(descriptor.value),
            });
            return this[key];
        },
    };
}
function debounceNextTickImpl(fn) {
    var args = null;
    var context = null;
    return debounced;
    function debounced() {
        var previous = args;
        args = [].slice.call(arguments);
        context = this;
        if (previous !== null)
            return;
        nextTick(next);
    }
    function next() {
        fn.apply(context, args);
        args = null;
        context = null;
    }
}

var sizeMap = {
    desktop: 'large',
    tablet: 'medium',
    mobile: 'small',
};
function decorator(fn) {
    return function argReceiver() {
        var fnArgs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            fnArgs[_i] = arguments[_i];
        }
        // Check if the decorator is being called without arguments (ex `@foo methodName() {}`)
        if (fnArgs.length === 3) {
            var target = fnArgs[0], key = fnArgs[1], descriptor = fnArgs[2];
            if (descriptor && (descriptor.value || descriptor.get)) {
                fnArgs = [];
                return descriptorChecker(target, key, descriptor);
            }
        }
        return descriptorChecker;
        // descriptorChecker determines whether a method or getter is being decorated
        // and replaces the appropriate key with the decorated function.
        function descriptorChecker(target, key, descriptor) {
            var _a;
            var descriptorKey = descriptor.value ? 'value' : 'get';
            return __assign(__assign({}, descriptor), (_a = {}, _a[descriptorKey] = fn.apply(void 0, __spreadArrays([descriptor[descriptorKey]], fnArgs)), _a));
        }
    };
}
var Throttle = decorator(throttle);
var fetchCache = {};
var tryEval = function (str, data, errors) {
    if (data === void 0) { data = {}; }
    var value = str;
    if (!(typeof value === 'string' && value.trim())) {
        return;
    }
    var useReturn = !(value.includes(';') || value.includes(' return '));
    var fn = function () {
        /* Intentionally empty */
    };
    try {
        if (Builder.isBrowser) {
            // tslint:disable-next-line:no-function-constructor-with-string-args
            // TODO: VM in node......
            fn = new Function('state', "with (state) {\n          " + (useReturn ? "return (" + value + ");" : value) + ";\n         }");
        }
    }
    catch (error) {
        if (Builder.isBrowser) {
            console.warn('Could not compile javascript', error);
        }
    }
    try {
        if (Builder.isBrowser) {
            return fn(data || {});
        }
        else {
            // Below is a hack to get certain code to *only* load in the server build, to not screw with
            // browser bundler's like rollup and webpack. Our rollup plugin strips these comments only
            // for the server build
            // tslint:disable:comment-format
            var VM = require('vm2').VM;
            return new VM({
                sandbox: __assign(__assign({}, data), { state: data }),
            }).run(value.replace(/^return /, ''));
            // tslint:enable:comment-format
        }
    }
    catch (error) {
        if (errors) {
            errors.push(error);
        }
        if (Builder.isBrowser) {
            console.warn('Builder custom code error:', error.message, 'in', str, error.stack);
        }
        else {
            console.debug('Builder custom code error:', error.message, 'in', str, error.stack);
            // Add to req.options.errors to return to client
        }
    }
    return;
};
function searchToObject(location) {
    var pairs = (location.search || '').substring(1).split('&');
    var obj = {};
    for (var i in pairs) {
        if (!(pairs[i] && typeof pairs[i] === 'string')) {
            continue;
        }
        var pair = pairs[i].split('=');
        obj[decodeURIComponent(pair[0])] = decodeURIComponent(pair[1]);
    }
    return obj;
}
var BuilderPage = /** @class */ (function (_super) {
    __extends(BuilderPage, _super);
    function BuilderPage(props) {
        var _this = _super.call(this, props) || this;
        _this.subscriptions = new Subscription();
        _this.onStateChange = new BehaviorSubject(null);
        _this.lastJsCode = '';
        _this.lastHttpRequests = '';
        _this.ref = null;
        _this.resizeListener = debounce(function () {
            var deviceSize = _this.deviceSizeState;
            if (deviceSize !== _this.state.state.deviceSize) {
                _this.setState(__assign(__assign({}, _this.state), { state: __assign(__assign({}, _this.state.state), { deviceSize: deviceSize }) }));
            }
        }, 200, { leading: false, trailing: true });
        _this.updateState = function (fn) {
            var nextState = produce(_this.state.state, function (draftState) {
                fn(draftState);
                // TODO: emit dom event - what element? global?
            });
            _this.setState({
                update: _this.updateState,
                state: nextState,
            });
            _this.notifyStateChange();
        };
        _this.onContentLoaded = function (data) {
            // TODO: if model is page... hmm
            if (_this.name === 'page' && Builder.isBrowser) {
                if (data) {
                    var title = data.title, description = data.description;
                    // if (title) {
                    //   document.title = title;
                    // }
                    // if (description) {
                    //   let descriptionTag = document.querySelector('meta[name="description"]');
                    //   if (!descriptionTag) {
                    //     descriptionTag = document.createElement('meta');
                    //     descriptionTag.setAttribute('name', 'description');
                    //     document.head.appendChild(descriptionTag);
                    //   }
                    //   descriptionTag!.setAttribute('content', description);
                    // }
                }
            }
            // Unsubscribe all? TODO: maybe don't continuous fire when editing.....
            if (_this.props.contentLoaded) {
                Builder.nextTick(function () {
                    if (_this.props.contentLoaded) {
                        _this.props.contentLoaded(data);
                    }
                });
            }
            if (data && data.inputs && Array.isArray(data.inputs) && data.inputs.length) {
                if (!data.state) {
                    data.state = {};
                }
                // TODO: may not want this... or make sure anything overriden
                // explitily sets to null
                data.inputs.forEach(function (input) {
                    if (input) {
                        if (input.name &&
                            input.defaultValue !== undefined &&
                            data.state[input.name] === undefined) {
                            data.state[input.name] = input.defaultValue;
                        }
                    }
                });
            }
            if (data && data.state) {
                _this.setState(__assign(__assign({}, _this.state), { state: __assign(__assign(__assign(__assign({ isBrowser: Builder.isBrowser }, _this.state.state), { location: _this.locationState, deviceSize: _this.deviceSizeState, device: _this.device }), data.state), _this.props.data) }));
            }
            // TODO: also throttle on edits maybe
            if (data && data.jsCode && Builder.isBrowser) {
                // Don't rerun js code when editing and not changed
                var skip = false;
                if (Builder.isEditing) {
                    if (_this.lastJsCode === data.jsCode) {
                        skip = true;
                    }
                    else {
                        _this.lastJsCode = data.jsCode;
                    }
                }
                if (!skip) {
                    var state_1 = _this.state.state;
                    var getState_1 = function () { return _this.state.state; };
                    var getUpdate_1 = function () { return _this.state.update; };
                    // TODO: move to helper and deep wrap like immer in case people make references
                    // TODO: on set auto run in update if not already
                    if (typeof Proxy !== 'undefined') {
                        state_1 = new Proxy(__assign({}, state_1), {
                            getOwnPropertyDescriptor: function (target, property) {
                                try {
                                    return Reflect.getOwnPropertyDescriptor(getState_1(), property);
                                }
                                catch (error) {
                                    return undefined;
                                }
                            },
                            // TODO: wrap other proxy properties
                            // TODO: ensure batching updates
                            set: function (target, key, value) {
                                // TODO: do these for deep sets from references hmm
                                // TODO: throttle these updates
                                getUpdate_1()(function (state) {
                                    Reflect.set(state, key, value);
                                });
                                return true;
                                // return Reflect.set(getState(), key, value)
                                // return false;
                            },
                            // to prevent variable doesn't exist errors with `with (state)`
                            has: function (target, property) {
                                try {
                                    // TODO: if dead trigger an immer update
                                    return Reflect.has(getState_1(), property);
                                }
                                catch (error) {
                                    return false;
                                }
                            },
                            get: function (object, property) {
                                if (property &&
                                    typeof property === 'string' &&
                                    property.endsWith('Item') &&
                                    !Reflect.has(getState_1(), property)) {
                                    // TODO: use $index to return a reference to the proxied version of item
                                    // so can be set as well
                                    return Reflect.get(state_1, property);
                                }
                                return Reflect.get(getState_1(), property);
                            },
                        });
                    }
                    // TODO: real editing method
                    try {
                        var result_1 = new Function('data', 'ref', 'state', 'update', 'element', 'Builder', 'builder', data.jsCode)(data, _this, state_1, _this.state.update, _this.ref, Builder, builder);
                        // TODO: what if is promise...
                        if (result_1 && typeof result_1 === 'object' && Object.keys(result_1).length) {
                            _this.state.update(function (state) {
                                Object.assign(result_1, state);
                            });
                        }
                        if (result_1 && typeof result_1.then === 'function') {
                            result_1.then(function (val) {
                                if (val && typeof val === 'object' && Object.keys(val).length) {
                                    _this.state.update(function (state) {
                                        Object.assign(val, state);
                                    });
                                }
                            });
                        }
                        // TODO: allow exports = { } syntax?
                        // TODO: do something with reuslt like view - methods, computed, actions, properties, template, etc etc
                    }
                    catch (error) {
                        if (Builder.isBrowser) {
                            console.warn('Builder custom code error:', error.message, error.stack);
                        }
                        else {
                            console.debug('Builder custom code error:', error.message, error.stack);
                            // Add to req.options.errors to return to client
                        }
                    }
                }
            }
            if (data && data.httpRequests /* || data.builderData @DEPRECATED */ && !_this.props.noAsync) {
                // Don't rerun http requests when editing and not changed
                var skip = false;
                if (Builder.isEditing) {
                    var httpRequestsString = attempt(function () { return JSON.stringify(data.httpRequests); });
                    if (_this.lastHttpRequests === httpRequestsString) {
                        skip = true;
                    }
                    else if (!isError(httpRequestsString)) {
                        _this.lastHttpRequests = httpRequestsString;
                    }
                }
                if (!skip) {
                    var _loop_1 = function (key) {
                        var url = data.httpRequests[key];
                        if (url && !_this.data[key]) {
                            // TODO: if Builder.isEditing and url patches https://builder.io/api/v2/content/{editingModel}
                            // Then use builder.get().subscribe(...)
                            if (Builder.isBrowser) {
                                var lastUrl_1 = _this.evalExpression(url);
                                var builderModelRe = /builder\.io\/api\/v2\/([^\/\?]+)/i;
                                var builderModelMatch = url.match(builderModelRe);
                                var model = builderModelMatch && builderModelMatch[1];
                                if (Builder.isEditing && model && builder.editingModel === model) {
                                    _this.subscriptions.add(builder.get(model).subscribe(function (data) {
                                        _this.state.update(function (state) {
                                            state[key] = data;
                                        });
                                    }));
                                }
                                else {
                                    _this.throttledHandleRequest(key, lastUrl_1);
                                    _this.subscriptions.add(_this.onStateChange.subscribe(function () {
                                        var newUrl = _this.evalExpression(url);
                                        if (newUrl !== lastUrl_1) {
                                            _this.throttledHandleRequest(key, newUrl);
                                            lastUrl_1 = newUrl;
                                        }
                                    }));
                                }
                            }
                            else {
                                _this.handleRequest(key, _this.evalExpression(url));
                            }
                        }
                    };
                    // TODO: another structure for this
                    for (var key in data.httpRequests) {
                        _loop_1(key);
                    }
                    // @DEPRECATED
                    // for (const key in data.builderData) {
                    //   const url = data.builderData[key]
                    //   if (url && !this.data[key]) {
                    //     this.handleBuilderRequest(key, this.evalExpression(url))
                    //   }
                    // }
                }
            }
        };
        _this.state = {
            state: __assign({ location: _this.locationState, deviceSize: _this.deviceSizeState, 
                // TODO: will user attributes be ready here?
                device: _this.device }, _this.props.data),
            update: _this.updateState,
        };
        return _this;
    }
    Object.defineProperty(BuilderPage.prototype, "name", {
        get: function () {
            return this.props.modelName || this.props.name; // || this.props.model
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderPage.prototype, "device", {
        // TODO: pass down with context
        get: function () {
            return builder.getUserAttributes().device || 'desktop';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderPage.prototype, "locationState", {
        get: function () {
            return __assign(__assign({}, pick(this.location, 'pathname', 'hostname', 'search', 'host')), { path: (this.location.pathname && this.location.pathname.split('/').slice(1)) || '', query: searchToObject(this.location) });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BuilderPage.prototype, "deviceSizeState", {
        // TODO: trigger state change on screen size change
        get: function () {
            // TODO: use context to pass this down on server
            return Builder.isBrowser
                ? sizes.getSizeForWidth(window.innerWidth)
                : sizeMap[this.device] || 'large';
        },
        enumerable: true,
        configurable: true
    });
    // TODO: different options per device size...........................
    // static renderInto(
    //   elementOrSelector: string | HTMLElement,
    //   props: BuilderPageProps = {},
    //   hydrate = false
    // ) {
    //   const element =
    //     elementOrSelector instanceof HTMLElement
    //       ? elementOrSelector
    //       : document.querySelector(elementOrSelector)
    //   if (!element) {
    //     return
    //   }
    //   if (hydrate) {
    //     return ReactDOM.hydrate(<BuilderPage {...props} />, element)
    //   }
    //   return ReactDOM.render(<BuilderPage {...props} />, element)
    // }
    BuilderPage.prototype.componentWillMount = function () {
        var key = this.props.apiKey;
        if (key && key !== builder.apiKey) {
            builder.apiKey = key;
        }
        if (this.props.content) {
            // TODO: this should be on didMount right bc of element ref??
            // TODO: possibly observe for change or throw error if changes
            this.onContentLoaded(this.props.content.data /*, this.props.content*/);
        }
    };
    BuilderPage.prototype.componentDidMount = function () {
        var _this = this;
        if (Builder.isIframe) {
            parent.postMessage({ type: 'builder.sdkInjected', data: { modelName: this.name } }, '*');
        }
        if (Builder.isBrowser) {
            window.addEventListener('resize', this.resizeListener);
            setTimeout(function () {
                window.dispatchEvent(new CustomEvent('builder:component:load', {
                    detail: {
                        ref: _this,
                    },
                }));
            });
        }
        if (typeof this.state.state.componentDidMount === 'function') {
            try {
                this.state.state.componentDidMount();
            }
            catch (err) {
                console.error(err);
            }
        }
    };
    BuilderPage.prototype.notifyStateChange = function () {
        var nextState = this.state.state;
        // TODO: only run the below once per tick...
        if (this.props.onStateChange) {
            this.props.onStateChange(nextState);
        }
        if (Builder.isBrowser) {
            window.dispatchEvent(new CustomEvent('builder:component:stateChange', {
                detail: {
                    state: nextState,
                    ref: this,
                },
            }));
        }
        this.onStateChange.next(nextState);
    };
    BuilderPage.prototype.processStateFromApi = function (state) {
        return state; //  mapValues(state, value => tryEval(value, this.data, this._errors))
    };
    Object.defineProperty(BuilderPage.prototype, "location", {
        get: function () {
            return this.props.location || (Builder.isBrowser ? location : {});
        },
        enumerable: true,
        configurable: true
    });
    BuilderPage.prototype.getCssFromFont = function (font) {
        if (!font) {
            return '';
        }
        // TODO: compute what font sizes are used and only load those.......
        var family = font.family + (font.kind && !font.kind.includes('#') ? ', ' + font.kind : '');
        var name = family.split(',')[0];
        var url = font.fileUrl ? font.fileUrl : font.files && font.files.regular;
        var str = '';
        if (url && family && name) {
            str += ("\n@font-face {\n  font-family: " + family + ";\n  src: local(\"" + family + "\"), url('" + url + "') format('woff2');\n  font-display: fallback;\n  font-weight: 400;\n}\n        ").trim();
        }
        if (font.files) {
            for (var weight in font.files) {
                // TODO: maybe limit number loaded
                var weightUrl = font.files[weight];
                if (weightUrl && weightUrl !== url) {
                    str += ("\n@font-face {\n  font-family: " + family + ";\n  src: url('" + weightUrl + "') format('woff2');\n  font-display: fallback;\n  font-weight: " + weight + ";\n}\n          ").trim();
                }
            }
        }
        return str;
    };
    BuilderPage.prototype.componentWillUnmount = function () {
        this.unsubscribe();
        if (Builder.isBrowser) {
            window.removeEventListener('resize', this.resizeListener);
        }
    };
    BuilderPage.prototype.getFontCss = function (data) {
        var _this = this;
        // TODO: separate internal data from external
        return (data.customFonts &&
            data.customFonts.length &&
            data.customFonts.map(function (font) { return _this.getCssFromFont(font); }).join(' '));
    };
    BuilderPage.prototype.getCss = function (data) {
        // .replace(/([^\s]|$)&([^\w])/g, '$1' + '.some-selector' + '$2')
        return (data.cssCode || '') + (this.getFontCss(data) || '');
    };
    Object.defineProperty(BuilderPage.prototype, "data", {
        get: function () {
            return __assign(__assign({}, this.props.data), this.state.state);
        },
        enumerable: true,
        configurable: true
    });
    BuilderPage.prototype.componentDidUpdate = function (prevProps) {
        var _this = this;
        // TODO: shallow diff
        if (this.props.data && prevProps.data !== this.props.data) {
            this.state.update(function (state) {
                Object.assign(state, _this.props.data);
            });
        }
        if (Builder.isEditing) {
            if (this.props.content && prevProps.content !== this.props.content) {
                this.onContentLoaded(this.props.content);
            }
        }
    };
    BuilderPage.prototype.render = function () {
        var _this = this;
        var content = this.props.content;
        return (
        // TODO: data attributes for model, id, etc?
        React.createElement(View, { "data-name": this.name },
            React.createElement(BuilderAsyncRequestsContext.Consumer, null, function (value) {
                _this._asyncRequests = value && value.requests;
                _this._errors = value && value.errors;
                _this._logs = value && value.logs;
                return (React.createElement(BuilderStoreContext.Provider, { value: __assign(__assign({}, _this.state), { state: _this.data }) },
                    React.createElement(BuilderContent, { inline: _this.props.inlineContent, 
                        // TODO: pass entry in
                        contentLoaded: _this.onContentLoaded, options: __assign(__assign({ entry: _this.props.entry, key: Builder.isEditing ? _this.name : _this.props.entry }, (content && size(content) && { initialContent: [content] })), _this.props.options), contentError: _this.props.contentError, modelName: _this.name || 'page' }, function (data, loading, fullData) {
                        // TODO: loading option - maybe that is what the children is or component prop
                        return data ? (React.createElement(View, { "data-builder-component": _this.name, "data-builder-content-id": fullData.id, "data-builder-variation-id": fullData.variationId },
                            React.createElement(BuilderBlocks, { emailMode: _this.props.emailMode, fieldName: "blocks", blocks: data.blocks }))) : loading ? (React.createElement(View, { "data-builder-component": _this.name }, _this.props.children)) : (React.createElement(View, { "data-builder-component": _this.name }));
                    })));
            })));
    };
    BuilderPage.prototype.evalExpression = function (expression) {
        var _this = this;
        var data = this.data;
        return expression.replace(/{{([^}]+)}}/g, function (match, group) { return tryEval(group, data, _this._errors); });
    };
    // TODO: customizable hm
    BuilderPage.prototype.throttledHandleRequest = function (propertyName, url) {
        return this.handleRequest(propertyName, url);
    };
    BuilderPage.prototype.handleRequest = function (propertyName, url) {
        return __awaiter(this, void 0, void 0, function () {
            var request, existing, promise_1, promise;
            var _this = this;
            return __generator(this, function (_a) {
                // TODO: Builder.isEditing = just checks if iframe and parent page is builder.io or localhost:1234
                if (Builder.isIframe && fetchCache[url]) {
                    this.updateState(function (ctx) {
                        ctx[propertyName] = fetchCache[url];
                    });
                    return [2 /*return*/, fetchCache[url]];
                }
                request = function () { return __awaiter(_this, void 0, void 0, function () {
                    var requestStart, json, result, err_1;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                requestStart = Date.now();
                                if (!Builder.isBrowser) {
                                    console.time('Fetch ' + url);
                                }
                                _a.label = 1;
                            case 1:
                                _a.trys.push([1, 4, 5, 6]);
                                return [4 /*yield*/, fetch(url)];
                            case 2:
                                result = _a.sent();
                                return [4 /*yield*/, result.json()];
                            case 3:
                                json = _a.sent();
                                return [3 /*break*/, 6];
                            case 4:
                                err_1 = _a.sent();
                                if (this._errors) {
                                    this._errors.push(err_1);
                                }
                                if (this._logs) {
                                    this._logs.push("Fetch to " + url + " errored in " + (Date.now() - requestStart) + "ms");
                                }
                                return [2 /*return*/];
                            case 5:
                                if (!Builder.isBrowser) {
                                    console.timeEnd('Fetch ' + url);
                                    if (this._logs) {
                                        this._logs.push("Fetched " + url + " in " + (Date.now() - requestStart) + "ms");
                                    }
                                }
                                return [7 /*endfinally*/];
                            case 6:
                                if (json) {
                                    if (Builder.isIframe) {
                                        fetchCache[url] = json;
                                    }
                                    // TODO: debounce next tick all of these when there are a bunch
                                    this.updateState(function (ctx) {
                                        ctx[propertyName] = json;
                                    });
                                }
                                return [2 /*return*/, json];
                        }
                    });
                }); };
                existing = this._asyncRequests &&
                    this._asyncRequests.find(function (req) { return isRequestInfo(req) && req.url === url; });
                if (existing) {
                    promise_1 = existing.promise;
                    promise_1.then(function (json) {
                        if (json) {
                            _this.updateState(function (ctx) {
                                ctx[propertyName] = json;
                            });
                        }
                    });
                    return [2 /*return*/, promise_1];
                }
                promise = request();
                Builder.nextTick(function () {
                    if (_this._asyncRequests) {
                        _this._asyncRequests.push(promise);
                    }
                });
                return [2 /*return*/, promise];
            });
        });
    };
    BuilderPage.prototype.unsubscribe = function () {
        if (this.subscriptions) {
            this.subscriptions.unsubscribe();
            this.subscriptions = new Subscription();
        }
    };
    BuilderPage.prototype.handleBuilderRequest = function (propertyName, optionsString) {
        var _this = this;
        var options = tryEval(optionsString, this.data, this._errors);
        // TODO: this will screw up for multiple bits of data
        if (this.subscriptions) {
            this.unsubscribe();
        }
        // TODO: don't unsubscribe and resubscribe every time data changes, will make a TON of requests if that's the case when editing...
        // I guess will be cached then
        if (options) {
            // TODO: unsubscribe on destroy
            this.subscriptions.add(builder.queueGetContent(options.model, options).subscribe(function (matches) {
                if (matches) {
                    _this.updateState(function (ctx) {
                        ctx[propertyName] = matches;
                    });
                }
            }));
        }
    };
    __decorate([
        debounceNextTick,
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], BuilderPage.prototype, "notifyStateChange", null);
    __decorate([
        Throttle(100, { leading: true, trailing: true }),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [String, String]),
        __metadata("design:returntype", void 0)
    ], BuilderPage.prototype, "throttledHandleRequest", null);
    return BuilderPage;
}(React.Component));

var BuilderMetaContext = React.createContext({
    emailMode: false,
    ampMode: false,
});

function BuilderBlock$1(options) {
    options.type = 'react';
    return Builder.Component(options);
}

var iconUrl = 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-text_fields-24px%20(1).svg?alt=media&token=12177b73-0ee3-42ca-98c6-0dd003de1929';
var Text = /** @class */ (function (_super) {
    __extends(Text, _super);
    function Text() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Text.prototype.render = function () {
        return (React.createElement(React.Fragment, null,
            React.createElement(HTML, { html: this.props.text || ' ' })));
    };
    Text = __decorate([
        BuilderBlock$1({
            name: 'Text',
            image: iconUrl,
            inputs: [
                {
                    name: 'text',
                    type: 'html',
                    required: true,
                    defaultValue: 'Enter some text...',
                },
            ],
            // Maybe optionally a function that takes in some params like block vs absolute, etc
            defaultStyles: {
                lineHeight: 'normal',
                height: 'auto',
                textAlign: 'center',
            },
        })
    ], Text);
    return Text;
}(React.Component));

var DEFAULT_ASPECT_RATIO = 0.7004048582995948;
var defaultBlocks /*: BuilderElement[] */ = [
    {
        '@type': '@builder.io/sdk:Element',
        responsiveStyles: {
            large: {
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'stretch',
                flexShrink: '0',
                position: 'relative',
                marginTop: '30px',
                textAlign: 'center',
                lineHeight: 'normal',
                height: 'auto',
            },
        },
        component: {
            name: 'Image',
            options: {
                image: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
                backgroundPosition: 'center',
                backgroundSize: 'cover',
                aspectRatio: DEFAULT_ASPECT_RATIO,
            },
        },
    },
    {
        '@type': '@builder.io/sdk:Element',
        responsiveStyles: {
            large: {
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'stretch',
                flexShrink: '0',
                position: 'relative',
                marginTop: '30px',
                textAlign: 'center',
                lineHeight: 'normal',
                height: 'auto',
            },
        },
        component: {
            name: 'Text',
            options: {
                text: '<p>Enter some text...</p>',
            },
        },
    },
];
var Columns = /** @class */ (function (_super) {
    __extends(Columns, _super);
    function Columns() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(Columns.prototype, "columns", {
        // TODO: Column interface
        get: function () {
            return this.props.columns || [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Columns.prototype, "gutterSize", {
        get: function () {
            return typeof this.props.space === 'number' ? this.props.space || 0 : 20;
        },
        enumerable: true,
        configurable: true
    });
    Columns.prototype.getWidth = function (index) {
        return (this.columns[index] && this.columns[index].width) || 100 / this.columns.length;
    };
    Columns.prototype.getColumnWidth = function (index) {
        var _a = this, columns = _a.columns, gutterSize = _a.gutterSize;
        var subtractWidth = (gutterSize * (columns.length - 1)) / columns.length;
        return "calc(" + this.getWidth(index) + "% - " + subtractWidth + "px)";
    };
    Object.defineProperty(Columns.prototype, "deviceSizeState", {
        get: function () {
            var sizeMap = {
                desktop: 'large',
                tablet: 'medium',
                mobile: 'small',
            };
            // TODO: use context to pass this down on server
            return Builder.isBrowser
                ? sizes.getSizeForWidth(window.innerWidth)
                : sizeMap[this.device] || 'large';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Columns.prototype, "device", {
        get: function () {
            return builder.getUserAttributes().device || 'desktop';
        },
        enumerable: true,
        configurable: true
    });
    Columns.prototype.render = function () {
        var _this = this;
        var _a = this, columns = _a.columns, gutterSize = _a.gutterSize;
        var size = this.deviceSizeState;
        var stack = sizeNames.indexOf(size) <= sizeNames.indexOf(this.props.stackColumnsAt);
        return (
        // FIXME: make more elegant
        React.createElement(React.Fragment, null,
            React.createElement(View, { style: { display: 'flex' } }, columns.map(function (col, index) {
                // TODO: pass size down in context
                return (React.createElement(React.Fragment, { key: index },
                    React.createElement(View
                    // TODO: handle links!
                    , __assign({}, (col.link ? { href: col.link } : null), { 
                        // TODO: generate width and margin-left as CSS instead so can override with pure CSS for best responsieness
                        // and no use of !important
                        style: {
                            display: 'flex',
                            flexDirection: 'column',
                            alignItems: 'stretch',
                        } }),
                        React.createElement(BuilderBlocks, { key: index, 
                            // TODO: childOf [parentBlocks]?
                            child: true, parentElementId: _this.props.builderBlock && _this.props.builderBlock.id, blocks: col.blocks, dataPath: "component.options.columns." + index + ".blocks" }))));
            }))));
    };
    Columns = __decorate([
        BuilderBlock$1({
            name: 'Columns',
            inputs: [
                {
                    name: 'columns',
                    type: 'array',
                    subFields: [
                        {
                            name: 'blocks',
                            type: 'array',
                            hideFromUI: true,
                            defaultValue: defaultBlocks,
                        },
                        {
                            name: 'width',
                            type: 'number',
                            hideFromUI: true,
                            helperText: 'Width %, e.g. set to 50 to fill half of the space',
                        },
                        {
                            name: 'link',
                            type: 'string',
                            helperText: 'Optionally set a url that clicking this column will link to',
                        },
                    ],
                    defaultValue: [{ blocks: defaultBlocks }, { blocks: defaultBlocks }],
                    onChange: function (options) {
                        function clearWidths() {
                            columns.forEach(function (col) {
                                col.delete('width');
                            });
                        }
                        var columns = options.get('columns');
                        if (Array.isArray(columns)) {
                            var containsColumnWithWidth = !!columns.find(function (col) { return col.get('width'); });
                            if (containsColumnWithWidth) {
                                var containsColumnWithoutWidth = !!columns.find(function (col) { return !col.get('width'); });
                                if (containsColumnWithoutWidth) {
                                    clearWidths();
                                }
                                else {
                                    var sumWidths = columns.reduce(function (memo, col) {
                                        return memo + col.get('width');
                                    }, 0);
                                    var widthsDontAddUp = sumWidths !== 100;
                                    if (widthsDontAddUp) {
                                        clearWidths();
                                    }
                                }
                            }
                        }
                    },
                },
                {
                    name: 'space',
                    type: 'number',
                    defaultValue: 20,
                    helperText: 'Size of gap between columns',
                    advanced: true,
                },
                {
                    name: 'stackColumnsAt',
                    type: 'string',
                    defaultValue: 'tablet',
                    helperText: 'Convert horizontal columns to vertical at what device size',
                    enum: ['tablet', 'mobile', 'never'],
                    advanced: true,
                },
                {
                    name: 'reverseColumnsWhenStacked',
                    type: 'boolean',
                    defaultValue: false,
                    helperText: 'When stacking columns for mobile devices, reverse the ordering',
                    advanced: true,
                },
            ],
        })
    ], Columns);
    return Columns;
}(React.Component));

var Embed = /** @class */ (function (_super) {
    __extends(Embed, _super);
    function Embed() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Embed.prototype.render = function () {
        return React.createElement(HTML, { html: this.props.content || ' ' });
    };
    Embed = __decorate([
        BuilderBlock$1({
            name: 'Embed',
            inputs: [
                {
                    name: 'url',
                    type: 'url',
                    required: true,
                    defaultValue: '',
                    helperText: 'e.g. enter a youtube url, google map, etc',
                    onChange: function (options) {
                        var url = options.get('url');
                        if (url) {
                            options.set('content', 'Loading...');
                            // TODO: get this out of here!
                            var apiKey = 'ae0e60e78201a3f2b0de4b';
                            return fetch("https://iframe.ly/api/iframely?url=" + url + "&api_key=" + apiKey)
                                .then(function (res) { return res.json(); })
                                .then(function (data) {
                                if (options.get('url') === url) {
                                    if (data.html) {
                                        options.set('content', data.html);
                                    }
                                    else {
                                        options.set('content', 'Invalid url, please try another');
                                    }
                                }
                            })
                                .catch(function (err) {
                                options.set('content', 'There was an error embedding this URL, please try again or another URL');
                            });
                        }
                        else {
                            options.delete('content');
                        }
                    },
                },
                {
                    name: 'content',
                    type: 'html',
                    defaultValue: "<div style=\"padding: 20px; text-align: center\">(Choose an embed URL)<div>",
                    hideFromUI: true,
                },
            ],
        })
    ], Embed);
    return Embed;
}(React.Component));

var CustomCode = /** @class */ (function (_super) {
    __extends(CustomCode, _super);
    function CustomCode() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomCode.prototype.componentDidMount = function () {
        // TODO: parse and run scripts (?)
    };
    CustomCode.prototype.render = function () {
        return React.createElement(HTML, { html: this.props.code || ' ' });
    };
    CustomCode = __decorate([
        BuilderBlock$1({
            name: 'Custom Code',
            inputs: [
                {
                    name: 'code',
                    type: 'longText',
                    required: true,
                    defaultValue: '<p>Hello there, I am custom HTML code!</p>',
                },
            ],
        })
    ], CustomCode);
    return CustomCode;
}(React.Component));

var DEFAULT_ASPECT_RATIO$1 = 0.7041;
var Image = /** @class */ (function (_super) {
    __extends(Image, _super);
    function Image() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // TODO
    // static universal: BuilderElement[] = []
    Image.prototype.render = function () {
        var _this = this;
        var _a = this.props, aspectRatio = _a.aspectRatio, builderBlock = _a.builderBlock;
        var children = this.props.builderBlock && this.props.builderBlock.children;
        return (
        // TODO: swap-in amp components hm
        // These styles may be bad... may need to remove this wrapper entirely hmm
        // <div style={{ position: 'relative', fontSize: 0 }}>
        React.createElement(BuilderMetaContext.Consumer, null, function (value) {
            return (React.createElement(React.Fragment, null,
                React.createElement(Image$1
                // alt={this.props.altText}
                // height={
                //   this.props.height || (aspectRatio ? Math.round(aspectRatio * 1000) : undefined)
                // }
                // width={
                //   this.props.width || (aspectRatio ? Math.round(1000 / aspectRatio) : undefined)
                // }
                // role={!this.props.altText ? 'presentation' : undefined}
                , { 
                    // alt={this.props.altText}
                    // height={
                    //   this.props.height || (aspectRatio ? Math.round(aspectRatio * 1000) : undefined)
                    // }
                    // width={
                    //   this.props.width || (aspectRatio ? Math.round(1000 / aspectRatio) : undefined)
                    // }
                    // role={!this.props.altText ? 'presentation' : undefined}
                    style: __assign({ resizeMode: _this.props.backgroundSize }, (aspectRatio && {
                        position: 'absolute',
                        height: '100%',
                        width: '100%',
                        left: 0,
                        top: 0,
                    })), resizeMode: _this.props.backgroundSize, 
                    // className="builder-image"
                    source: { uri: _this.props.image } }),
                aspectRatio ? (React.createElement(View, { pointerEvents: "none", 
                    // className="builder-image-sizer"
                    style: {
                        width: '100%',
                        paddingTop: aspectRatio * 100 + '%',
                    } })) : null,
                children && children.length ? (React.createElement(View, { style: {
                        display: 'flex',
                        flexDirection: 'column',
                        alignItems: 'stretch',
                        position: 'absolute',
                        top: 0,
                        left: 0,
                        width: '100%',
                        height: '100%',
                    } }, children.map(function (block, index) { return (React.createElement(BuilderBlock, { key: block.id, block: block })); }))) : null));
        })
        // <div
        //   style={{
        //     position: 'absolute',
        //     top: 0,
        //     left: 0,
        //     right: 0,
        //     bottom: 0,
        //     backgroundImage: `url("${this.props.image}")`,
        //     backgroundSize: this.props.backgroundSize,
        //     backgroundRepeat: this.props.backgroundRepeat,
        //     backgroundPosition: this.props.backgroundPosition,
        //   }}
        //   className="builder-image"
        // />
        );
    };
    Image = __decorate([
        BuilderBlock$1({
            name: 'Image',
            image: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4',
            defaultStyles: {
                minHeight: '20px',
                minWidth: '20px',
                overflow: 'hidden',
            },
            canHaveChildren: true,
            inputs: [
                {
                    name: 'image',
                    type: 'file',
                    // TODO: auto convert png to jpg when there is no transparency
                    allowedFileTypes: ['jpeg', 'jpg', 'png', 'svg'],
                    required: true,
                    // TODO: something better
                    defaultValue: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
                    onChange: function (options) {
                        var DEFAULT_ASPECT_RATIO = 0.7041;
                        function loadImage(url, timeout) {
                            if (timeout === void 0) { timeout = 60000; }
                            return new Promise(function (resolve, reject) {
                                var img = document.createElement('img');
                                var loaded = false;
                                img.onload = function () {
                                    loaded = true;
                                    resolve(img);
                                };
                                img.addEventListener('error', function (event) {
                                    console.warn('Image load failed', event.error);
                                    reject(event.error);
                                });
                                img.src = url;
                                setTimeout(function () {
                                    if (!loaded) {
                                        reject(new Error('Image load timed out'));
                                    }
                                }, timeout);
                            });
                        }
                        function round(num) {
                            return Math.round(num * 1000) / 1000;
                        }
                        // // TODO
                        var value = options.get('image');
                        var aspectRatio = options.get('aspectRatio');
                        if (value && (!aspectRatio || aspectRatio === DEFAULT_ASPECT_RATIO)) {
                            return loadImage(value).then(function (img) {
                                var possiblyUpdatedAspectRatio = options.get('aspectRatio');
                                if (options.get('image') === value &&
                                    (!possiblyUpdatedAspectRatio || possiblyUpdatedAspectRatio === DEFAULT_ASPECT_RATIO)) {
                                    if (img.width && img.height) {
                                        options.set('aspectRatio', round(img.height / img.width));
                                        options.set('height', img.height);
                                        options.set('width', img.width);
                                    }
                                }
                            });
                        }
                    },
                },
                {
                    name: 'backgroundSize',
                    type: 'text',
                    defaultValue: 'cover',
                    enum: [
                        { label: 'contain', value: 'contain', helperText: 'The image should never get cropped' },
                        {
                            label: 'cover',
                            value: 'cover',
                            helperText: "The image should fill it's box, cropping when needed",
                        },
                    ],
                },
                {
                    name: 'backgroundPosition',
                    type: 'text',
                    defaultValue: 'center',
                    enum: [
                        'center',
                        'top',
                        'left',
                        'right',
                        'bottom',
                        'top left',
                        'top right',
                        'bottom left',
                        'bottom right',
                    ],
                },
                {
                    name: 'height',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'width',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'aspectRatio',
                    type: 'number',
                    helperText: "This is the ratio of height/width, e.g. set to 1.5 for a 300px wide and 200px tall photo. Set to 0 to not force the image to maintain it's aspect ratio",
                    advanced: true,
                    defaultValue: DEFAULT_ASPECT_RATIO$1,
                },
                {
                    name: 'altText',
                    type: 'string',
                    hideFromUI: true,
                    advanced: true,
                },
            ],
        })
    ], Image);
    return Image;
}(React.Component));

var DEFAULT_ASPECT_RATIO$2 = 0.7004048582995948;
var Video = /** @class */ (function (_super) {
    __extends(Video, _super);
    function Video() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.video = null;
        return _this;
    }
    Video.prototype.componentDidMount = function () { };
    Video.prototype.render = function () {
        var aspectRatio = this.props.aspectRatio;
        return (React.createElement(View, { style: { position: 'relative' } },
            React.createElement(ReactNativeVideo, { paused: !this.props.autoPlay, key: this.props.video || 'no-src', poster: this.props.posterImage, source: { uri: this.props.video }, muted: this.props.muted, controls: this.props.controls, repeat: this.props.loop, resizeMode: this.props.fit, style: __assign({ width: '100%', height: '100%', borderRadius: 1 }, (aspectRatio
                    ? {
                        position: 'absolute',
                    }
                    : null)) }),
            aspectRatio ? (React.createElement(View, { pointerEvents: "none", style: {
                    width: '100%',
                    paddingTop: aspectRatio * 100 + '%',
                } })) : null));
    };
    Video = __decorate([
        BuilderBlock$1({
            name: 'Video',
            image: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-videocam-24px%20(1).svg?alt=media&token=49a84e4a-b20e-4977-a650-047f986874bb',
            inputs: [
                {
                    name: 'video',
                    type: 'file',
                    allowedFileTypes: ['mp4'],
                    defaultValue: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/assets%2FKQlEmWDxA0coC3PK6UvkrjwkIGI2%2F28cb070609f546cdbe5efa20e931aa4b?alt=media&token=912e9551-7a7c-4dfb-86b6-3da1537d1a7f',
                    required: true,
                    onChange: function (options) {
                        var DEFAULT_ASPECT_RATIO = 0.7004048582995948;
                        function loadImage(url, timeout) {
                            if (timeout === void 0) { timeout = 60000; }
                            return new Promise(function (resolve, reject) {
                                var img = document.createElement('img');
                                var loaded = false;
                                img.onload = function () {
                                    loaded = true;
                                    resolve(img);
                                };
                                img.addEventListener('error', function (event) {
                                    console.warn('Image load failed', event.error);
                                    reject(event.error);
                                });
                                img.src = url;
                                setTimeout(function () {
                                    if (!loaded) {
                                        reject(new Error('Image load timed out'));
                                    }
                                }, timeout);
                            });
                        }
                        function round(num) {
                            return Math.round(num * 1000) / 1000;
                        }
                        // // TODO
                        var value = options.get('image');
                        var aspectRatio = options.get('aspectRatio');
                        if (value && (!aspectRatio || aspectRatio === DEFAULT_ASPECT_RATIO)) {
                            return loadImage(value).then(function (img) {
                                var possiblyUpdatedAspectRatio = options.get('aspectRatio');
                                if (options.get('image') === value &&
                                    (!possiblyUpdatedAspectRatio || possiblyUpdatedAspectRatio === DEFAULT_ASPECT_RATIO)) {
                                    if (img.width && img.height) {
                                        options.set('aspectRatio', round(img.height / img.width));
                                    }
                                }
                            });
                        }
                    },
                },
                {
                    name: 'posterImage',
                    type: 'file',
                    allowedFileTypes: ['jpeg', 'png'],
                    helperText: 'Image to show before the video plays',
                },
                {
                    name: 'autoPlay',
                    type: 'boolean',
                    defaultValue: true,
                },
                {
                    name: 'controls',
                    type: 'boolean',
                    defaultValue: false,
                },
                {
                    name: 'muted',
                    type: 'boolean',
                    defaultValue: true,
                },
                {
                    name: 'loop',
                    type: 'boolean',
                    defaultValue: true,
                },
                {
                    name: 'playsInline',
                    type: 'boolean',
                    defaultValue: true,
                },
                {
                    name: 'fit',
                    type: 'text',
                    defaultValue: 'cover',
                    enum: ['contain', 'cover', 'fill', 'auto'],
                },
                {
                    name: 'position',
                    type: 'text',
                    defaultValue: 'center',
                    enum: [
                        'center',
                        'top',
                        'left',
                        'right',
                        'bottom',
                        'top left',
                        'top right',
                        'bottom left',
                        'bottom right',
                    ],
                },
                {
                    name: 'height',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'width',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'aspectRatio',
                    type: 'number',
                    hideFromUI: true,
                    defaultValue: DEFAULT_ASPECT_RATIO$2,
                },
            ],
        })
    ], Video);
    return Video;
}(React.Component));

var Symbol$1 = /** @class */ (function (_super) {
    __extends(Symbol, _super);
    function Symbol() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(Symbol.prototype, "placeholder", {
        get: function () {
            return (React.createElement(Text$1, { style: { padding: 10 } }, "Symbols let you reuse dynamic elements across your content. Please choose a model and entry for this symbol."));
        },
        enumerable: true,
        configurable: true
    });
    Symbol.prototype.render = function () {
        var symbol = this.props.symbol;
        if (!symbol) {
            return this.placeholder;
        }
        var model = symbol.model, entry = symbol.entry, data = symbol.data, content = symbol.content, inline = symbol.inline;
        if (!model && !inline) {
            return this.placeholder;
        }
        return (React.createElement(BuilderPage, { modelName: model, entry: entry, data: data, inlineContent: symbol.inline, content: content, options: { key: Builder.isEditing ? undefined : entry } }, this.props.children));
    };
    Symbol = __decorate([
        BuilderBlock$1({
            // Builder:Symbol
            name: 'Symbol',
            inputs: [
                {
                    name: 'symbol',
                    type: 'uiSymbol',
                },
            ],
        })
    ], Symbol);
    return Symbol;
}(React.Component));

var Button = /** @class */ (function (_super) {
    __extends(Button, _super);
    function Button() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Button.prototype.render = function () {
        return (
        // TODO: emit click event
        React.createElement(TouchableOpacity
        // href={this.props.link}
        // target={this.props.openLinkInNewTab ? '_blank' : undefined}
        , __assign({}, this.props.attributes), this.props.text));
    };
    Button = __decorate([
        BuilderBlock$1(__assign({ name: 'Core:Button', image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F81a15681c3e74df09677dfc57a615b13', defaultStyles: {
                // TODO: make min width more intuitive and set one
                appearance: 'none',
                paddingTop: '15px',
                paddingBottom: '15px',
                paddingLeft: '25px',
                paddingRight: '25px',
                backgroundColor: '#3898EC',
                color: 'white',
                borderRadius: '4px',
                textAlign: 'center',
            }, inputs: [
                {
                    name: 'text',
                    type: 'text',
                    defaultValue: 'Click me!',
                },
                {
                    // TODO: custom link form editor to link to other pages, scroll to
                    // etc
                    name: 'link',
                    type: 'url',
                },
                {
                    // TODO: custom link form editor to link to other pages, scroll to
                    // etc
                    name: 'openLinkInNewTab',
                    type: 'boolean',
                    defaultValue: false,
                    friendlyName: 'Open link in new tab',
                },
            ] }, {
            noWrap: true,
        }))
    ], Button);
    return Button;
}(React.Component));

// TODO: acceptsChildren option?
var Section = /** @class */ (function (_super) {
    __extends(Section, _super);
    function Section() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Section.prototype.render = function () {
        return (React.createElement(View, { style: {
                // margin: 'auto',
                // TODO: maybe remove height: '100%'
                height: '100%',
                width: '100%',
                alignSelf: 'stretch',
                flexGrow: 1,
                // boxSizing: 'border-box',
                maxWidth: this.props.maxWidth,
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'stretch',
                marginLeft: 'auto',
                marginRight: 'auto',
            } }, this.props.builderBlock &&
            this.props.builderBlock.children &&
            this.props.builderBlock.children.map(function (block, index) { return (React.createElement(BuilderBlock, { key: block.id, block: block })); })));
    };
    Section = __decorate([
        BuilderBlock$1({
            name: 'Core:Section',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F682efef23ace49afac61748dd305c70a',
            inputs: [
                {
                    name: 'maxWidth',
                    type: 'number',
                    defaultValue: 1200,
                },
            ],
            defaultStyles: {
                paddingLeft: '20px',
                paddingRight: '20px',
                paddingTop: '50px',
                paddingBottom: '50px',
                marginTop: '0px',
                width: '100vw',
                marginLeft: 'calc(50% - 50vw)',
            },
            canHaveChildren: true,
            // TODO: defaults that deep merge and can be anyting - responsive styles, etc
            defaultChildren: [
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            textAlign: 'center',
                        },
                    },
                    component: {
                        name: 'Text',
                        options: {
                            text: "<p><b>I am a section! My content keeps from getting too wide, so that it's easy to read even on big screens.</b></p><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur</p>",
                        },
                    },
                },
            ],
        })
    ], Section);
    return Section;
}(React.Component));

// TODO: change to slick grid
var StateProvider = /** @class */ (function (_super) {
    __extends(StateProvider, _super);
    function StateProvider() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StateProvider.prototype.render = function () {
        var _this = this;
        return (React.createElement(BuilderStoreContext.Consumer, null, function (state) { return (React.createElement(BuilderStoreContext.Provider, { value: __assign(__assign({}, state), { state: __assign(__assign({}, state.state), _this.props.state) }) }, _this.props.builderBlock &&
            _this.props.builderBlock.children &&
            _this.props.builderBlock.children.map(function (block, index) { return (React.createElement(BuilderBlock, { block: block, index: index, key: block.id })); }))); }));
    };
    StateProvider = __decorate([
        BuilderBlock$1({
            // Builder:StateProvider?
            name: 'Builder:StateProvider',
            // TODO: default children
            canHaveChildren: true,
            hideFromInsertMenu: true,
        })
    ], StateProvider);
    return StateProvider;
}(React.Component));

var Form = /** @class */ (function (_super) {
    __extends(Form, _super);
    function Form() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ref = null;
        // TODO: link this state to global state and allow togglign the modes in
        // the style and or data editor. TODO: for now some kind of input for preview state
        // that only impacts in the editor?
        _this.state = {
            state: 'unsubmitted',
            // TODO: separate response and error?
            respnoseData: null,
            formErrorMessage: '',
        };
        return _this;
    }
    Object.defineProperty(Form.prototype, "submissionState", {
        get: function () {
            return (Builder.isEditing && this.props.previewState) || this.state.state;
        },
        enumerable: true,
        configurable: true
    });
    Form.prototype.render = function () {
        var _this = this;
        return (
        // TODO: JS data bindings
        React.createElement(BuilderStoreContext.Consumer, null, function (state) { return (React.createElement(BuilderStoreContext.Provider, { value: __assign(__assign({}, state), { state: __assign(__assign({}, state.state), { formErrorMessage: _this.state.formErrorMessage }) }) },
            React.createElement(View
            // validate={this.props.validate}
            // ref={ref => (this.ref = ref)}
            , __assign({ 
                // validate={this.props.validate}
                // ref={ref => (this.ref = ref)}
                action: !_this.props.sendWithJs && _this.props.action, method: _this.props.method, name: _this.props.name }, _this.props.attributes),
                _this.props.builderBlock &&
                    _this.props.builderBlock.children &&
                    _this.props.builderBlock.children.map(function (block, index) { return (React.createElement(BuilderBlock, { key: block.id, block: block })); }),
                _this.submissionState === 'error' && (React.createElement(BuilderBlocks, { dataPath: "errorMessage", blocks: _this.props.errorMessage })),
                _this.submissionState === 'sending' && (React.createElement(BuilderBlocks, { dataPath: "sendingMessage", blocks: _this.props.sendingMessage })),
                _this.submissionState === 'error' && _this.state.respnoseData && (
                // TODO: tag to edit
                React.createElement(Text$1
                // className="builder-form-error-text"
                , { 
                    // className="builder-form-error-text"
                    style: { padding: 10, color: 'red', textAlign: 'center' } }, JSON.stringify(_this.state.respnoseData, null, 2))),
                _this.submissionState === 'success' && (React.createElement(BuilderBlocks, { dataPath: "successMessage", blocks: _this.props.successMessage }))))); }));
    };
    Form = __decorate([
        BuilderBlock$1({
            name: 'Form:Form',
            // editableTags: ['builder-form-error']
            defaults: {
                responsiveStyles: {
                    large: {
                        marginTop: '15px',
                        paddingBottom: '15px',
                    },
                },
            },
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fef36d2a846134910b64b88e6d18c5ca5',
            inputs: [
                {
                    name: 'sendSubmissionsTo',
                    type: 'string',
                    // TODO: builder, email
                    // Later - more integrations like mailchimp
                    enum: ['zapier', 'custom'],
                    hideFromUI: true,
                    defaultValue: 'custom',
                },
                {
                    name: 'sendWithJs',
                    type: 'boolean',
                    helperText: 'Set to false to use basic html form action',
                    defaultValue: true,
                    showIf: 'options.get("sendSubmissionsTo") === "custom"',
                },
                {
                    name: 'name',
                    type: 'string',
                    showIf: 'options.get("sendSubmissionsTo") === "zapier"',
                },
                {
                    name: 'action',
                    type: 'string',
                    helperText: 'URL to send the form data to',
                    showIf: 'options.get("sendSubmissionsTo") === "custom"',
                },
                {
                    name: 'contentType',
                    type: 'string',
                    defaultValue: 'application/json',
                    advanced: true,
                    // TODO: do automatically if file input
                    enum: ['application/json', 'multipart/formdata', 'application/x-www-form-urlencoded'],
                    showIf: 'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true',
                },
                {
                    name: 'method',
                    type: 'string',
                    showIf: 'options.get("sendSubmissionsTo") === "custom"',
                    advanced: true,
                },
                {
                    name: 'successUrl',
                    type: 'url',
                    helperText: 'Optional URL to redirect the user to on form submission success',
                    showIf: 'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true',
                },
                {
                    name: 'resetFormOnSubmit',
                    type: 'boolean',
                    showIf: function (options) {
                        return options.get('sendSubmissionsTo') === 'custom' && options.get('sendWithJs') === true;
                    },
                    advanced: true,
                },
                // TODO: maybe
                // {
                //   name: 'apiErrorMessageField',
                //   type: 'text',
                //   helperText: 'URL to redirect the user to on form submission success',
                //   showIf: 'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true'
                // },
                {
                    // editState?
                    name: 'previewState',
                    type: 'string',
                    enum: ['unsubmitted', 'sending', 'success', 'error'],
                    helperText: 'Choose a state to edit, e.g. choose "success" to show what users see on success and edit the message',
                    showIf: 'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true',
                },
                {
                    name: 'successMessage',
                    type: 'uiBlocks',
                    hideFromUI: true,
                    defaultValue: [
                        {
                            '@type': '@builder.io/sdk:Element',
                            responsiveStyles: {
                                large: {
                                    marginTop: '10px',
                                },
                            },
                            component: {
                                name: 'Text',
                                options: {
                                    text: '<span>Thanks!</span>',
                                },
                            },
                        },
                    ],
                },
                {
                    name: 'validate',
                    type: 'boolean',
                    defaultValue: true,
                    advanced: true,
                },
                {
                    name: 'errorMessagePath',
                    type: 'text',
                    advanced: true,
                    helperText: 'Path to where to get the error message from in a JSON response to display to the user, e.g. "error.message" for a response like { "error": { "message": "this username is taken" }}',
                },
                {
                    name: 'errorMessage',
                    type: 'uiBlocks',
                    hideFromUI: true,
                    defaultValue: [
                        {
                            '@type': '@builder.io/sdk:Element',
                            responsiveStyles: {
                                large: {
                                    marginTop: '10px',
                                },
                            },
                            bindings: {
                                'component.options.text': 'state.formErrorMessage || block.component.options.text',
                            },
                            component: {
                                name: 'Text',
                                options: {
                                    // TODO: how pull in API message
                                    text: '<span>Form submission error :( Please check your answers and try again</span>',
                                },
                            },
                        },
                    ],
                },
                {
                    name: 'sendingMessage',
                    type: 'uiBlocks',
                    hideFromUI: true,
                    defaultValue: [
                        {
                            '@type': '@builder.io/sdk:Element',
                            responsiveStyles: {
                                large: {
                                    marginTop: '10px',
                                },
                            },
                            component: {
                                name: 'Text',
                                options: {
                                    // TODO: how pull in API message
                                    text: '<span>Sending...</span>',
                                },
                            },
                        },
                    ],
                },
                __assign(__assign({ name: 'customHeaders', type: 'map' }, {
                    valueType: {
                        type: 'string',
                    },
                }), { advanced: true, showIf: 'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true' }),
            ],
            noWrap: true,
            // TODO: defaultChildren with two inputs and submit button
            canHaveChildren: true,
            defaultChildren: [
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            marginTop: '10px',
                        },
                    },
                    component: {
                        name: 'Text',
                        options: {
                            text: '<span>Enter your name</span>',
                        },
                    },
                },
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            marginTop: '10px',
                        },
                    },
                    component: {
                        name: 'Form:Input',
                        options: {
                            name: 'name',
                            placeholder: 'Jane Doe',
                        },
                    },
                },
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            marginTop: '10px',
                        },
                    },
                    component: {
                        name: 'Text',
                        options: {
                            text: '<span>Enter your email</span>',
                        },
                    },
                },
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            marginTop: '10px',
                        },
                    },
                    component: {
                        name: 'Form:Input',
                        options: {
                            name: 'email',
                            placeholder: 'jane@doe.com',
                        },
                    },
                },
                {
                    '@type': '@builder.io/sdk:Element',
                    responsiveStyles: {
                        large: {
                            marginTop: '10px',
                        },
                    },
                    component: {
                        name: 'Form:SubmitButton',
                        options: {
                            text: 'Submit',
                        },
                    },
                },
            ],
        })
    ], Form);
    return Form;
}(React.Component));

var FormInput = /** @class */ (function (_super) {
    __extends(FormInput, _super);
    function FormInput() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormInput.prototype.render = function () {
        return (React.createElement(TextInput, __assign({ key: Builder.isEditing && this.props.defaultValue ? this.props.defaultValue : 'default-key', placeholder: this.props.placeholder, type: this.props.type, name: this.props.name, value: this.props.value, defaultValue: this.props.defaultValue }, this.props.attributes)));
    };
    FormInput = __decorate([
        BuilderBlock$1({
            name: 'Form:Input',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fad6f37889d9e40bbbbc72cdb5875d6ca',
            inputs: [
                {
                    name: 'type',
                    type: 'text',
                    enum: [
                        'text',
                        'number',
                        'email',
                        'url',
                        'checkbox',
                        'radio',
                        'range',
                        'date',
                        'datetime-local',
                        'search',
                        'tel',
                        'time',
                        'month',
                        'week',
                        'color',
                        'hidden',
                    ],
                    defaultValue: 'text',
                },
                // TODO: handle value vs default value automatically like ng-model
                {
                    name: 'defaultValue',
                    type: 'string',
                },
                {
                    name: 'value',
                    type: 'string',
                    advanced: true,
                },
                {
                    name: 'placeholder',
                    type: 'string',
                    defaultValue: 'Hello there',
                },
                {
                    name: 'name',
                    type: 'string',
                },
                {
                    name: 'required',
                    type: 'boolean',
                    defaultValue: false,
                },
            ],
            // TODO
            // TODO: call editorHooks?
            // ...({
            //   hooks: {
            //     'ElementLayout:shiftBottomSide': (element: Element, amount: number, snap: boolean) => {
            //       // TODO: either update line height or split the padding padding on bottom sides hmm
            //     }
            //   } as any,
            // }),
            noWrap: true,
            defaultStyles: {
                paddingTop: '10px',
                paddingBottom: '10px',
                paddingLeft: '10px',
                paddingRight: '10px',
                borderRadius: '3px',
                borderWidth: '1px',
                borderStyle: 'solid',
                borderColor: '#ccc',
            },
        })
    ], FormInput);
    return FormInput;
}(React.Component));

// TODO: spec all of these as generic builder elements
// and codegen to Vue, React, Angular.........
var FormSubmitButton = /** @class */ (function (_super) {
    __extends(FormSubmitButton, _super);
    function FormSubmitButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormSubmitButton.prototype.render = function () {
        return (React.createElement(Button$1, __assign({ type: "submit" }, this.props.attributes),
            React.createElement(HTML, { html: this.props.text || ' ' })));
    };
    FormSubmitButton = __decorate([
        BuilderBlock$1({
            name: 'Form:SubmitButton',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fdf2820ffed1f4349a94c40b3221f5b98',
            defaultStyles: {
                appearance: 'none',
                paddingTop: '15px',
                paddingBottom: '15px',
                paddingLeft: '25px',
                paddingRight: '25px',
                backgroundColor: '#3898EC',
                color: 'white',
                borderRadius: '4px',
                cursor: 'pointer',
            },
            inputs: [
                {
                    name: 'text',
                    type: 'text',
                    defaultValue: 'Click me',
                },
            ],
            noWrap: true,
        })
    ], FormSubmitButton);
    return FormSubmitButton;
}(React.Component));

var Label = /** @class */ (function (_super) {
    __extends(Label, _super);
    function Label() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Label.prototype.render = function () {
        return React.createElement(HTML, { html: this.props.text || ' ' });
    };
    Label = __decorate([
        BuilderBlock$1({
            name: 'Form:Label',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F9322342f04b545fb9a8091cd801dfb5b',
            inputs: [
                {
                    name: 'text',
                    type: 'text',
                    defaultValue: 'Label',
                },
                {
                    name: 'for',
                    type: 'text',
                    helperText: 'The name of the input this label is for',
                    advanced: true,
                },
            ],
            noWrap: true,
        })
    ], Label);
    return Label;
}(React.Component));

var FormSelect = /** @class */ (function (_super) {
    __extends(FormSelect, _super);
    function FormSelect() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormSelect.prototype.render = function () {
        var options = this.props.options;
        return (React.createElement(Picker, __assign({ value: this.props.value, key: Builder.isEditing && this.props.defaultValue ? this.props.defaultValue : 'default-key', defaultValue: this.props.defaultValue, name: this.props.name }, this.props.attributes), options &&
            options.map(function (option) { return (React.createElement(Picker.Item, { value: option.value, label: option.name || option.value })); })));
    };
    FormSelect = __decorate([
        BuilderBlock$1({
            name: 'Form:Select',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F83acca093fb24aaf94dee136e9a4b045',
            defaultStyles: {
                alignSelf: 'flex-start',
            },
            inputs: [
                {
                    name: 'options',
                    type: 'list',
                    required: true,
                    subFields: [
                        {
                            name: 'value',
                            type: 'text',
                            required: true,
                        },
                        {
                            name: 'name',
                            type: 'text',
                        },
                    ],
                    defaultValue: [
                        {
                            value: 'option 1',
                        },
                        {
                            value: 'option 2',
                        },
                    ],
                },
                {
                    name: 'defaultValue',
                    type: 'string',
                },
                {
                    name: 'value',
                    type: 'string',
                    advanced: true,
                },
                {
                    name: 'name',
                    type: 'string',
                },
                {
                    name: 'required',
                    type: 'boolean',
                    defaultValue: false,
                },
            ],
            noWrap: true,
        })
    ], FormSelect);
    return FormSelect;
}(React.Component));

var TextArea = /** @class */ (function (_super) {
    __extends(TextArea, _super);
    function TextArea() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextArea.prototype.render = function () {
        return (React.createElement(TextInput, __assign({ placeholder: this.props.placeholder, name: this.props.name, value: this.props.value, defaultValue: this.props.defaultValue }, this.props.attributes)));
    };
    TextArea = __decorate([
        BuilderBlock$1({
            name: 'Form:TextArea',
            image: 'https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Ff74a2f3de58c4c3e939204e5b6b8f6c3',
            inputs: [
                {
                    advanced: true,
                    name: 'value',
                    type: 'string',
                },
                {
                    name: 'defaultValue',
                    type: 'string',
                },
                {
                    name: 'placeholder',
                    type: 'string',
                    defaultValue: 'Hello there',
                },
                {
                    name: 'name',
                    type: 'string',
                },
                {
                    name: 'required',
                    type: 'boolean',
                    defaultValue: false,
                },
            ],
            defaultStyles: {
                paddingTop: '10px',
                paddingBottom: '10px',
                paddingLeft: '10px',
                paddingRight: '10px',
                borderRadius: '3px',
                borderWidth: '1px',
                borderStyle: 'solid',
                borderColor: '#ccc',
            },
            noWrap: true,
        })
    ], TextArea);
    return TextArea;
}(React.Component));

var Img = /** @class */ (function (_super) {
    __extends(Img, _super);
    function Img() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Img.prototype.render = function () {
        var attributes = this.props.attributes || {};
        return (React.createElement(Image$1, __assign({ source: { uri: this.props.image || attributes.src } }, this.props.attributes)));
    };
    Img = __decorate([
        BuilderBlock$1({
            // friendlyName?
            name: 'Raw:Img',
            hideFromInsertMenu: true,
            image: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4',
            inputs: [
                {
                    name: 'image',
                    type: 'file',
                    allowedFileTypes: ['jpeg', 'jpg', 'png', 'svg'],
                    required: true,
                },
            ],
            noWrap: true,
        })
    ], Img);
    return Img;
}(React.Component));

Builder.isReact = true;
//

export default builder;
export { BuilderAsyncRequestsContext, BuilderBlock$1 as BuilderBlock, BuilderBlock as BuilderBlockComponent, BuilderBlocks, BuilderPage as BuilderComponent, BuilderContent, BuilderMetaContext, BuilderPage, BuilderStoreContext, Button, Columns, CustomCode, Embed, Form, FormInput, FormSelect, FormSubmitButton, Image, Img, Label, Section, StateProvider, Symbol$1 as Symbol, Text, TextArea, Video, stringToFunction };
//# sourceMappingURL=builder-react-native.esm.js.map
